@@ -1,5 +1,4 @@
 <?php
-
 /**
  * Zend Framework
  *
@@ -15,7 +14,8 @@
  *
  * @category   Zend
  * @package    Zend_Gdata
- * @copyright  Copyright (c) 2006-2007 Zend Technologies USA Inc. (http://www.zend.com)
+ * @subpackage Demos
+ * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 
@@ -41,59 +41,40 @@
  * argument to set_include_path in the code below.
  *
  * NOTE: As this is sample code, not all of the functions do full error
- * handling.  Please see getEvent for an example of how errors could
- * be handled and the online code samples for additional information.
+ * handling.  
  */
 
-// ************************ BEGIN WWW CONFIGURATION ************************
-
 /**
- * Docs username. This is the username used for your Google Documents account. 
- * This value is only used when accessing this demo on a web server.
- *
- * For example, your login for Google Documents may look like 
- * 'foo@bar.com.invalid'.
+ * @see Zend_Loader
  */
-define('DOCS_USERNAME', 'jeffreyscudderinternaltest@gmail.com');
-
-/**
- * Docs password. This is the password associated with the above
- * username. This value is only used when accessing this demo on a
- * web server.
- */
-define('DOCS_PASSWORD', 'Iwtgd2006');
-
-/**
- * Login password. This password is used to protect your account from
- * unauthorized access when running this demo on a web server.
- *
- * If this field is blank, all access will be denied. A blank password
- * field is not the same as no password (which is disallowed for
- * security reasons).
- *
- * NOTE: While we could technically just ask the user for their Google Docs
- *       credentials, the ClientLogin API is not intended for direct use by
- *       web applications. If you are the only user of the application, this
- *       is fine--- but you should not ask other users to enter their
- *       credentials via your web application.
- */
-define('LOGIN_PASSWORD', '');
-
-// ************************* END WWW CONFIGURATION *************************
-
-
 require_once 'Zend/Loader.php';
+
+/**
+ * @see Zend_Gdata
+ */
 Zend_Loader::loadClass('Zend_Gdata');
+
+/**
+ * @see Zend_Gdata_AuthSub
+ */
 Zend_Loader::loadClass('Zend_Gdata_AuthSub');
+
+/**
+ * @see Zend_Gdata_ClientLogin
+ */
 Zend_Loader::loadClass('Zend_Gdata_ClientLogin');
+
+/**
+ * @see Zend_Gdata_Docs
+ */
 Zend_Loader::loadClass('Zend_Gdata_Docs');
 
 /**
  * Returns a HTTP client object with the appropriate headers for communicating
  * with Google using the ClientLogin credentials supplied.
  *
- * @param string $user The username, in e-mail address format, to authenticate
- * @param string $pass The password for the user specified
+ * @param  string $user The username, in e-mail address format, to authenticate
+ * @param  string $pass The password for the user specified
  * @return Zend_Http_Client
  */
 function getClientLoginHttpClient($user, $pass)
@@ -108,8 +89,8 @@ function getClientLoginHttpClient($user, $pass)
 /**
  * Display list of valid commands.
  *
- * @param string $executable The name of the current script. This is
- *      usually available as $argv[0].
+ * @param  string $executable The name of the current script. This is usually available as $argv[0].
+ * @return void
  */
 function displayHelp($executable)
 {
@@ -129,10 +110,10 @@ function displayHelp($executable)
  *
  * If no arguments are provided, usage information will be provided.
  *
- * @param array $argv The array of command line arguments provided by PHP.
- *          $argv[0] should be the current executable name or '-' if
- *          not available.
- * @param int $argc The size of $argv.
+ * @param  array   $argv The array of command line arguments provided by PHP.
+ *                       $argv[0] should be the current executable name or '-' if not available.
+ * @param  integer $argc The size of $argv.
+ * @return void
  */
 function runCLIVersion($argv, $argc)
 {
@@ -228,9 +209,10 @@ function runCLIVersion($argv, $argc)
  * Displays the titles for the Google Documents entries in the feed. In HTML 
  * mode, the titles are links which point to the HTML version of the document.
  *
- * @param Zend_Gdata_Docs_DocumentListFeed $feed
- * @param boolean $html True if output should be formatted for display in a 
- *     web browser
+ * @param  Zend_Gdata_Docs_DocumentListFeed $feed
+ * @param  boolean                          $html True if output should be formatted for display in
+ *                                          a web browser
+ * @return void
  */
 function printDocumentsFeed($feed, $html) 
 {
@@ -264,10 +246,10 @@ function printDocumentsFeed($feed, $html)
  * Obtain a list of all of a user's docs.google.com documents and print the 
  * titles to the command line.
  *
- * @param Zend_Gdata_Docs $docs The service object to use for communicating 
- *     with the Google Documents server.
- * @param boolean $html True if output should be formatted for display in a 
- *     web browser.
+ * @param  Zend_Gdata_Docs $client The service object to use for communicating with the Google
+ *                                 Documents server.
+ * @param  boolean         $html   True if output should be formatted for display in a web browser.
+ * @return void
  */
 function retrieveAllDocuments($client, $html) 
 {
@@ -282,10 +264,10 @@ function retrieveAllDocuments($client, $html)
  * Obtain a list of all of a user's docs.google.com word processing 
  * documents and print the titles to the command line.
  *
- * @param Zend_Gdata_Docs $docs The service object to use for communicating 
- *     with the Google Documents server.
- * @param boolean $html True if output should be formatted for display in a 
- *     web browser.
+ * @param  Zend_Gdata_Docs $client The service object to use for communicating with the Google
+ *                                 Documents server.
+ * @param  boolean         $html   True if output should be formatted for display in a web browser.
+ * @return void
  */
 function retrieveWPDocs($client, $html) 
 {
@@ -301,10 +283,10 @@ function retrieveWPDocs($client, $html)
  * Obtain a list of all of a user's docs.google.com spreadsheets 
  * documents and print the titles to the command line.
  *
- * @param Zend_Gdata_Docs $docs The service object to use for communicating 
- *     with the Google Documents server.
- * @param boolean $html True if output should be formatted for display in a 
- *     web browser.
+ * @param  Zend_Gdata_Docs $client The service object to use for communicating with the Google
+ *                                 Documents server.
+ * @param  boolean         $html   True if output should be formatted for display in a web browser.
+ * @return void
  */
 function retrieveSpreadsheets($client, $html) 
 {
@@ -321,11 +303,11 @@ function retrieveSpreadsheets($client, $html)
  * which match the specified search criteria and print the titles to the 
  * command line.
  *
- * @param Zend_Gdata_Docs $docs The service object to use for communicating 
- *     with the Google Documents server.
- * @param boolean $html True if output should be formatted for display in a 
- *     web browser.
- * @param string $query The search query to use
+ * @param  Zend_Gdata_Docs $client The service object to use for communicating with the Google
+ *                                 Documents server.
+ * @param  boolean         $html   True if output should be formatted for display in a web browser.
+ * @param  string          $query  The search query to use
+ * @return void
  */
 function fullTextSearch($client, $html, $query) 
 {
@@ -340,19 +322,22 @@ function fullTextSearch($client, $html, $query)
 /**
  * Upload the specified document
  *
- * @param Zend_Gdata_Docs $docs The service object to use for communicating
- *     with the Google Documents server.
- * @param boolean $html True if output should be formatted for display in a
- *     web browser.
- * @param string $originalFileName The name of the file to be uploaded. The
- *     mime type of the file is determined from the extension on this file
- *     name. For example, test.csv is uploaded as a comma seperated volume
- *     and converted into a spreadsheet.
- * @param string $temporaryFileLocation (optional) The file in which the
- *     data for the document is stored. This is used when the file has been
- *     uploaded from the client's machine to the server and is stored in
- *     a temporary file which does not have an extension. If this parameter
- *     is null, the file is read from the originalFileName.
+ * @param  Zend_Gdata_Docs $docs                  The service object to use for communicating with
+ *                                                the Google Documents server.
+ * @param  boolean         $html                  True if output should be formatted for display in
+ *                                                a web browser.
+ * @param  string          $originalFileName      The name of the file to be uploaded. The mime type
+ *                                                of the file is determined from the extension on
+ *                                                this file name. For example, test.csv is uploaded
+ *                                                as a comma seperated volume and converted into a
+ *                                                spreadsheet.
+ * @param  string          $temporaryFileLocation (optional) The file in which the data for the
+ *                                                document is stored. This is used when the file has
+ *                                                been uploaded from the client's machine to the
+ *                                                server and is stored in a temporary file which
+ *                                                does not have an extension. If this parameter is
+ *                                                null, the file is read from the originalFileName.
+ * @return void
  */
 function uploadDocument($docs, $html, $originalFileName,
                         $temporaryFileLocation) {
@@ -394,8 +379,9 @@ function uploadDocument($docs, $html, $originalFileName,
  *       having a single-file sample.
  *
  *
- * @param boolean $displayMenu (optional) If set to true, a navigation
- *          menu is displayed at the top of the page. Default is true.
+ * @param  boolean $displayMenu (optional) If set to true, a navigation menu is displayed at the top
+ *                              of the page. Default is true.
+ * @return void
  */
 function startHTML($displayMenu = true)
 {
@@ -542,8 +528,9 @@ function startHTML($displayMenu = true)
 /**
  * Writes the HTML epilogue for this app and exit.
  *
- * @param boolean $displayBackButton (optional) If true, displays a
- *          link to go back at the bottom of the page. Defaults to false.
+ * @param  boolean $displayBackButton (optional) If true, displays a link to go back at the bottom
+ *                                    of the page. Defaults to false.
+ * @return void
  */
 function endHTML($displayBackButton = false)
 {
@@ -562,6 +549,8 @@ exit();
 /**
  * Displays a notice indicating that a login password needs to be
  * set before continuing.
+ *
+ * @return void
  */
 function displayPasswordNotSetNotice()
 {
@@ -580,6 +569,8 @@ function displayPasswordNotSetNotice()
 
 /**
  * Displays a notice indicating that authentication to Google Apps failed.
+ *
+ * @return void
  */
 function displayAuthenticationFailedNotice()
 {
@@ -598,6 +589,9 @@ function displayAuthenticationFailedNotice()
  * a link to the AuthSub URL.
  *
  * Uses getAuthSubUrl() to get the URL which the user must visit to authenticate
+ *
+ * @param  string $linkText
+ * @return void
  */
 function requestUserLogin($linkText)
 {
@@ -685,6 +679,8 @@ function getCurrentUrl()
 
 /**
  * Display the main menu for running in a web browser.
+ *
+ * @return void
  */
 function displayMenu()
 {
@@ -707,6 +703,8 @@ function displayMenu()
 
 /**
  * Log the current user out of the application.
+ *
+ * @return void
  */
 function logout()
 {
@@ -725,6 +723,8 @@ session_destroy();
 
 /**
  * Processes loading of this sample code through a web browser.
+ *
+ * @return void
  */
 function runWWWVersion()
 {
@@ -838,6 +838,8 @@ function runWWWVersion()
 
 /**
  * Display the menu for running in a web browser.
+ *
+ * @return void
  */
 function displayListMenu()
 {
@@ -875,6 +877,8 @@ function displayListMenu()
 
 /**
  * Display the menu for running in a web browser.
+ *
+ * @return void
  */
 function displayQueryMenu() 
 {
@@ -896,6 +900,8 @@ function displayQueryMenu()
 
 /**
  * Display the menu for running in a web browser.
+ *
+ * @return void
  */
 function displayUploadMenu()
 {
@@ -932,4 +938,3 @@ if (!isset($_SERVER["HTTP_HOST"]))  {
         endHTML(true);
     }
 }
-
