@@ -425,6 +425,28 @@ class Zend_Controller_ActionTest extends PHPUnit_Framework_TestCase
         $controller->scriptAction();
         $this->assertContains('Inside custom/renderScript.php', $response->getBody());
     }
+
+    public function testMissingActionExceptionsDifferFromMissingMethods()
+    {
+        try {
+            $this->_controller->bogusAction();
+            $this->fail('Invalid action should throw exception');
+        } catch (Zend_Controller_Exception $e) {
+            $this->assertRegexp('/^Action.*?(does not exist and was not trapped in __call\(\))$/', $e->getMessage());
+            $this->assertContains('bogus', $e->getMessage());
+            $this->assertNotContains('bogusAction', $e->getMessage());
+            $this->assertEquals(404, $e->getCode());
+        }
+
+        try {
+            $this->_controller->bogus();
+            $this->fail('Invalid method should throw exception');
+        } catch (Zend_Controller_Exception $e) {
+            $this->assertRegexp('/^Method.*?(does not exist and was not trapped in __call\(\))$/', $e->getMessage());
+            $this->assertContains('bogus', $e->getMessage());
+            $this->assertEquals(500, $e->getCode());
+        }
+    }
 }
 
 class Zend_Controller_ActionTest_TestController extends Zend_Controller_Action
