@@ -2,22 +2,14 @@
 // Call Zend_Controller_Dispatcher_StandardTest::main() if this source file is executed directly.
 if (!defined("PHPUnit_MAIN_METHOD")) {
     define("PHPUnit_MAIN_METHOD", "Zend_Controller_Dispatcher_StandardTest::main");
-
-    $basePath = realpath(dirname(__FILE__) . str_repeat(DIRECTORY_SEPARATOR . '..', 4));
-
-    set_include_path(
-        $basePath . DIRECTORY_SEPARATOR . 'tests'
-        . PATH_SEPARATOR . $basePath . DIRECTORY_SEPARATOR . 'library'
-        . PATH_SEPARATOR . get_include_path()
-    );
 }
 
-require_once "PHPUnit/Framework/TestCase.php";
-require_once "PHPUnit/Framework/TestSuite.php";
+require_once dirname(__FILE__) . '/../../../TestHelper.php';
 
 require_once 'Zend/Controller/Dispatcher/Standard.php';
 require_once 'Zend/Controller/Action/HelperBroker.php';
 require_once 'Zend/Controller/Request/Http.php';
+require_once 'Zend/Controller/Request/Simple.php';
 require_once 'Zend/Controller/Response/Cli.php';
 
 class Zend_Controller_Dispatcher_StandardTest extends PHPUnit_Framework_TestCase 
@@ -32,22 +24,23 @@ class Zend_Controller_Dispatcher_StandardTest extends PHPUnit_Framework_TestCase
      */
     public static function main()
     {
-        require_once "PHPUnit/TextUI/TestRunner.php";
-
         $suite  = new PHPUnit_Framework_TestSuite("Zend_Controller_Dispatcher_StandardTest");
         $result = PHPUnit_TextUI_TestRunner::run($suite);
     }
 
     public function setUp()
     {
+        if (isset($this->error)) {
+            unset($this->error);
+        }
         $front = Zend_Controller_Front::getInstance();
         $front->resetInstance();
-        $front->setControllerDirectory(array(
+        Zend_Controller_Action_HelperBroker::removeHelper('viewRenderer');
+        $this->_dispatcher = new Zend_Controller_Dispatcher_Standard();
+        $this->_dispatcher->setControllerDirectory(array(
             'default' => dirname(__FILE__) . DIRECTORY_SEPARATOR . '..' . DIRECTORY_SEPARATOR . '_files',
             'admin'   => dirname(__FILE__) . DIRECTORY_SEPARATOR . '..' . DIRECTORY_SEPARATOR . '_files' . DIRECTORY_SEPARATOR . 'Admin'
         ));
-        Zend_Controller_Action_HelperBroker::removeHelper('viewRenderer');
-        $this->_dispatcher = new Zend_Controller_Dispatcher_Standard();
     }
 
     public function tearDown()
@@ -364,9 +357,11 @@ class Zend_Controller_Dispatcher_StandardTest extends PHPUnit_Framework_TestCase
 
     public function testModuleSubdirControllerFound()
     {
-        Zend_Controller_Front::getInstance()->addControllerDirectory(
-            dirname(__FILE__) . DIRECTORY_SEPARATOR . '..' . DIRECTORY_SEPARATOR . '_files' . DIRECTORY_SEPARATOR . 'modules' . DIRECTORY_SEPARATOR . 'foo' . DIRECTORY_SEPARATOR . 'controllers',
-            'foo'
+        Zend_Controller_Front::getInstance()
+            ->setDispatcher($this->_dispatcher)
+            ->addControllerDirectory(
+                dirname(__FILE__) . DIRECTORY_SEPARATOR . '..' . DIRECTORY_SEPARATOR . '_files' . DIRECTORY_SEPARATOR . 'modules' . DIRECTORY_SEPARATOR . 'foo' . DIRECTORY_SEPARATOR . 'controllers',
+                'foo'
         );
 
         $request = new Zend_Controller_Request_Http();
@@ -394,6 +389,17 @@ class Zend_Controller_Dispatcher_StandardTest extends PHPUnit_Framework_TestCase
         $this->assertTrue($this->_dispatcher->isValidModule('default'));
         $this->assertTrue($this->_dispatcher->isValidModule('admin'));
         $this->assertFalse($this->_dispatcher->isValidModule('bogus'));
+        $this->assertFalse($this->_dispatcher->isValidModule(null));
+        $this->assertFalse($this->_dispatcher->isValidModule($this));
+        $this->assertFalse($this->_dispatcher->isValidModule(array()));
+    }
+
+    /**
+     * @see ZF-3034
+     */
+    public function testIsValidModuleShouldNormalizeModuleName()
+    {
+        $this->assertTrue($this->_dispatcher->isValidModule('Admin'));
     }
 
     public function testSanelyDiscardOutputBufferOnException()
@@ -426,6 +432,155 @@ class Zend_Controller_Dispatcher_StandardTest extends PHPUnit_Framework_TestCase
         $this->assertEquals($this->_dispatcher->getDefaultControllerName(), $request->getControllerName());
         $this->assertNull($request->getActionName());
     }
+
+    public function testLoadClassLoadsControllerInDefaultModuleWithoutModulePrefix()
+    {
+        $request = new Zend_Controller_Request_Simple();
+        $request->setControllerName('empty');
+        $class = $this->_dispatcher->getControllerClass($request);
+        $this->assertEquals('EmptyController', $class);
+        $test = $this->_dispatcher->loadClass($class);
+        $this->assertEquals($class, $test);
+        $this->assertTrue(class_exists($class));
+    }
+
+    public function testLoadClassLoadsControllerInSpecifiedModuleWithModulePrefix()
+    {
+        Zend_Controller_Front::getInstance()
+            ->setDispatcher($this->_dispatcher)
+            ->addModuleDirectory(dirname(__FILE__) . '/../_files/modules');
+        $request = new Zend_Controller_Request_Simple();
+        $request->setControllerName('index')
+                ->setModuleName('bar');
+        $class = $this->_dispatcher->getControllerClass($request);
+        $this->assertEquals('IndexController', $class);
+        $test = $this->_dispatcher->loadClass($class);
+        $this->assertEquals('Bar_IndexController', $test);
+        $this->assertTrue(class_exists($test));
+    }
+
+    public function testLoadClassLoadsControllerInDefaultModuleWithModulePrefixWhenRequested()
+    {
+        Zend_Controller_Front::getInstance()
+            ->setDispatcher($this->_dispatcher)
+            ->addModuleDirectory(dirname(__FILE__) . '/../_files/modules');
+        $this->_dispatcher->setDefaultModule('foo')
+                          ->setParam('prefixDefaultModule', true);
+        $request = new Zend_Controller_Request_Simple();
+        $request->setControllerName('index');
+        $class = $this->_dispatcher->getControllerClass($request);
+        $this->assertEquals('IndexController', $class);
+        $test = $this->_dispatcher->loadClass($class);
+        $this->assertEquals('Foo_IndexController', $test);
+        $this->assertTrue(class_exists($test));
+    }
+
+    /**
+     * ZF-2435
+     */
+    public function testCanRemoveControllerDirectory()
+    {
+        Zend_Controller_Front::getInstance()
+            ->setDispatcher($this->_dispatcher)
+            ->addModuleDirectory(dirname(__FILE__) . '/../_files/modules');
+        $dirs = $this->_dispatcher->getControllerDirectory();
+        $this->_dispatcher->removeControllerDirectory('foo');
+        $test = $this->_dispatcher->getControllerDirectory();
+        $this->assertNotEquals($dirs, $test);
+        $this->assertFalse(array_key_exists('foo', $test));
+    }
+
+    /**
+     * ZF-2693
+     */
+    public function testCamelCasedActionsNotRequestedWithWordSeparatorsShouldNotResolve()
+    {
+        $request = new Zend_Controller_Request_Http();
+        $request->setModuleName('admin');
+        $request->setControllerName('foo-bar');
+        $request->setActionName('bazBat');
+        $this->assertTrue($this->_dispatcher->isDispatchable($request), var_export($this->_dispatcher->getControllerDirectory(), 1));
+
+        $response = new Zend_Controller_Response_Cli();
+        try {
+            $this->_dispatcher->dispatch($request, $response);
+            $this->fail('Invalid camelCased action should raise exception');
+        } catch (Zend_Controller_Exception $e) {
+            $this->assertContains('does not exist', $e->getMessage());
+        }
+    }
+
+    /**
+     * ZF-2693
+     */
+    public function testCamelCasedActionsNotRequestedWithWordSeparatorsShouldResolveIfForced()
+    {
+        $this->_dispatcher->setParam('useCaseSensitiveActions', true);
+        $request = new Zend_Controller_Request_Http();
+        $request->setModuleName('admin');
+        $request->setControllerName('foo-bar');
+        $request->setActionName('bazBat');
+        $this->assertTrue($this->_dispatcher->isDispatchable($request), var_export($this->_dispatcher->getControllerDirectory(), 1));
+
+        $response = new Zend_Controller_Response_Cli();
+        $oldLevel = error_reporting(0);
+        try {
+            $this->_dispatcher->dispatch($request, $response);
+            $body = $this->_dispatcher->getResponse()->getBody();
+            error_reporting($oldLevel);
+            $this->assertContains("Admin_FooBar::bazBat action called", $body, $body);
+        } catch (Zend_Controller_Exception $e) {
+            error_reporting($oldLevel);
+            $this->fail('camelCased actions should succeed when forced');
+        }
+    }
+
+    public function handleErrors($errno, $errstr)
+    {
+        $this->error = $errstr;
+    }
+
+    /**
+     * @see ZF-2693
+     */
+    public function testForcingCamelCasedActionsNotRequestedWithWordSeparatorsShouldRaiseNotices()
+    {
+        $this->_dispatcher->setParam('useCaseSensitiveActions', true);
+        $request = new Zend_Controller_Request_Http();
+        $request->setModuleName('admin');
+        $request->setControllerName('foo-bar');
+        $request->setActionName('bazBat');
+        $this->assertTrue($this->_dispatcher->isDispatchable($request), var_export($this->_dispatcher->getControllerDirectory(), 1));
+
+        $response = new Zend_Controller_Response_Cli();
+        set_error_handler(array($this, 'handleErrors'));
+        try {
+            $this->_dispatcher->dispatch($request, $response);
+            $body = $this->_dispatcher->getResponse()->getBody();
+            restore_error_handler();
+            $this->assertTrue(isset($this->error));
+            $this->assertContains('deprecated', $this->error);
+        } catch (Zend_Controller_Exception $e) {
+            restore_error_handler();
+            $this->fail('camelCased actions should succeed when forced');
+        }
+    }
+
+    /**
+     * @see ZF-2887
+     */
+    public function testGetControllerClassThrowsExceptionIfNoDefaultModuleDefined()
+    {
+        $this->_dispatcher->setControllerDirectory(array());
+
+        $request = new Zend_Controller_Request_Simple();
+        $request->setControllerName('empty');
+        try {
+            $class = $this->_dispatcher->getControllerClass($request);
+        } catch (Zend_Controller_Exception $e) {
+            $this->assertContains('No default module', $e->getMessage());
+        }
+    }
 }
 
 // Call Zend_Controller_Dispatcher_StandardTest::main() if this source file is executed directly.
