@@ -21,6 +21,7 @@ require_once 'Zend/Controller/Response/Cli.php';
 require_once 'Zend/Controller/Dispatcher/Standard.php';
 require_once 'Zend/Controller/Router/Rewrite.php';
 require_once 'Zend/Controller/Action/HelperBroker.php';
+require_once 'Zend/Controller/Action/Helper/Url.php';
 require_once 'Zend/Controller/Action/Helper/ViewRenderer.php';
 
 class Zend_Controller_FrontTest extends PHPUnit_Framework_TestCase
@@ -69,6 +70,23 @@ class Zend_Controller_FrontTest extends PHPUnit_Framework_TestCase
         $this->assertSame(array(), $this->_controller->getControllerDirectory());
     }
 
+    /**
+     * @see ZF-3145
+     */
+    public function testResetInstanceShouldResetHelperBroker()
+    {
+        Zend_Controller_Action_HelperBroker::addHelper(new Zend_Controller_Action_Helper_ViewRenderer());
+        Zend_Controller_Action_HelperBroker::addHelper(new Zend_Controller_Action_Helper_Url());
+        $helpers = Zend_Controller_Action_HelperBroker::getExistingHelpers();
+        $this->assertTrue(is_array($helpers));
+        $this->assertFalse(empty($helpers));
+
+        $this->_controller->resetInstance();
+        $helpers = Zend_Controller_Action_HelperBroker::getExistingHelpers();
+        $this->assertTrue(is_array($helpers));
+        $this->assertTrue(empty($helpers));
+    }
+
     public function testSetGetRequest()
     {
         $request = new Zend_Controller_Request_Http();
@@ -516,6 +534,61 @@ class Zend_Controller_FrontTest extends PHPUnit_Framework_TestCase
         $this->assertContains('modules' . DIRECTORY_SEPARATOR . 'default', $controllerDirs['default']);
     }
 
+    /**#@+
+     * @see ZF-2910
+     */
+    public function testShouldAllowRetrievingCurrentModuleDirectory()
+    {
+        $this->testAddModuleDirectory();
+        $request = new Zend_Controller_Request_Http();
+        $request->setModuleName('bar');
+        $this->_controller->setRequest($request);
+        $dir = $this->_controller->getModuleDirectory();
+        $this->assertContains('modules' . DIRECTORY_SEPARATOR . 'bar', $dir);
+        $this->assertNotContains('controllers', $dir);
+    }
+
+    public function testShouldAllowRetrievingSpecifiedModuleDirectory()
+    {
+        $this->testAddModuleDirectory();
+        $dir = $this->_controller->getModuleDirectory('foo');
+        $this->assertContains('modules' . DIRECTORY_SEPARATOR . 'foo', $dir);
+        $this->assertNotContains('controllers', $dir);
+    }
+
+    public function testShouldReturnNullWhenRetrievingNonexistentModuleDirectory()
+    {
+        $this->testAddModuleDirectory();
+        $this->assertNull($this->_controller->getModuleDirectory('bogus-foo-bar'));
+    }
+    /**#@-*/
+
+    /**
+     * ZF-2435
+     */
+    public function testCanRemoveIndividualModuleDirectory()
+    {
+        $moduleDir = dirname(__FILE__) . DIRECTORY_SEPARATOR . '_files' . DIRECTORY_SEPARATOR . 'modules';
+        $this->_controller->addModuleDirectory($moduleDir);
+        $controllerDirs = $this->_controller->getControllerDirectory();
+        $this->_controller->removeControllerDirectory('foo');
+        $test = $this->_controller->getControllerDirectory();
+        $this->assertNotEquals($controllerDirs, $test);
+        $this->assertFalse(array_key_exists('foo', $test));
+    }
+    
+    public function testAddModuleDirectoryThrowsExceptionForInvalidDirectory()
+    {
+        $moduleDir = 'doesntexist';
+        try {
+            $this->_controller->addModuleDirectory($moduleDir);
+            $this->fail('Exception expected but not thrown');
+        }catch(Exception $e){
+            $this->assertType('Zend_Exception',$e);
+            $this->assertRegExp('/Directory \w+ not readable/',$e->getMessage());
+        }
+    }
+
     public function testGetControllerDirectoryByModuleName()
     {
         $moduleDir = dirname(__FILE__) . DIRECTORY_SEPARATOR . '_files' . DIRECTORY_SEPARATOR . 'modules';
