@@ -1,24 +1,46 @@
 <?php
+/**
+ * Zend Framework
+ *
+ * LICENSE
+ *
+ * This source file is subject to the new BSD license that is bundled
+ * with this package in the file LICENSE.txt.
+ * It is also available through the world-wide-web at this URL:
+ * http://framework.zend.com/license/new-bsd
+ * If you did not receive a copy of the license and are unable to
+ * obtain it through the world-wide-web, please send an email
+ * to license@zend.com so we can send you a copy immediately.
+ *
+ * @category   Zend
+ * @package    Zend_Controller
+ * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @version    $Id: HttpTest.php 8533 2008-03-04 18:40:32Z ralph $
+ */
+
+/**
+ * Test helper
+ */
+require_once dirname(__FILE__) . '/../../../TestHelper.php';
+
 // Call Zend_Controller_Response_HttpTest::main() if this source file is executed directly.
-if (!defined("PHPUnit_MAIN_METHOD")) {
-    define("PHPUnit_MAIN_METHOD", "Zend_Controller_Response_HttpTest::main");
-
-    $basePath = realpath(dirname(__FILE__) . str_repeat(DIRECTORY_SEPARATOR . '..', 3));
-
-    set_include_path(
-        $basePath . DIRECTORY_SEPARATOR . 'tests'
-        . PATH_SEPARATOR . $basePath . DIRECTORY_SEPARATOR . 'library'
-        . PATH_SEPARATOR . get_include_path()
-    );
+if (!defined('PHPUnit_MAIN_METHOD')) {
+    define('PHPUnit_MAIN_METHOD', 'Zend_Controller_Response_HttpTest::main');
 }
 
-require_once "PHPUnit/Framework/TestCase.php";
-require_once "PHPUnit/Framework/TestSuite.php";
-
 require_once 'Zend/Controller/Response/Http.php';
 require_once 'Zend/Controller/Response/Exception.php';
 
-class Zend_Controller_Response_HttpTest extends PHPUnit_Framework_TestCase 
+/**
+ * @category   Zend
+ * @package    Zend_Controller
+ * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ */
+class Zend_Controller_Response_HttpTest extends PHPUnit_Framework_TestCase
 {
     /**
      * @var Zend_Http_Response
@@ -164,9 +186,17 @@ class Zend_Controller_Response_HttpTest extends PHPUnit_Framework_TestCase
         $this->assertEquals($expected . $additional, $this->_response->getBody());
     }
 
+    /**
+     * SKIPPED - This test is untestable in the CLI environment.  PHP ignores all
+     * header() calls (which are used by Http_Abstract::setHeader()), thus, anything
+     * that is expected to be found in http headers when inserted via header(), will
+     * not be found.  In addition, headers_sent() should always return false, until
+     * real output is sent to the console.
+     */
     public function test__toString()
     {
-        $skipHeadersTest = headers_sent();
+
+        //$skipHeadersTest = headers_sent();
 
         $this->_response->setHeader('Content-Type', 'text/plain');
         $this->_response->setBody('Content');
@@ -174,6 +204,11 @@ class Zend_Controller_Response_HttpTest extends PHPUnit_Framework_TestCase
 
         $expected = 'Content; and more content.';
         $result = $this->_response->__toString();
+        
+        $this->assertSame($expected, $result);
+        return;
+        
+        // header checking will not work
 
         if (!$skipHeadersTest) {
             $this->assertTrue(headers_sent());
@@ -245,13 +280,23 @@ class Zend_Controller_Response_HttpTest extends PHPUnit_Framework_TestCase
         }
     }
 
+    /**
+     * Same problem as test__toString()
+     *
+     * Specifically for this test, headers_sent will always be false, so canSentHeaders() will
+     * never actually throw an exception since the conditional exception code will never trigger
+     */
     public function testCanSendHeadersIndicatesFileAndLine()
     {
+        $this->markTestSkipped();
+        return;
+        
         $this->_response->headersSentThrowsException = true;
         try {
             $this->_response->canSendHeaders(true);
             $this->fail('canSendHeaders() should throw exception');
         } catch (Exception $e) {
+            var_dump($e->getMessage());
             $this->assertRegExp('/headers already sent in .+, line \d+$/', $e->getMessage());
         }
     }
@@ -429,8 +474,8 @@ class Zend_Controller_Response_HttpTest extends PHPUnit_Framework_TestCase
         $this->_response->appendBody($string3, 'string3');
 
         $expected = array(
-            'string1' => $string1, 
-            'string2' => $string2, 
+            'string1' => $string1,
+            'string2' => $string2,
             'string3' => $string3
         );
 
@@ -538,10 +583,25 @@ class Zend_Controller_Response_HttpTest extends PHPUnit_Framework_TestCase
         $this->assertTrue(0 < count($exceptions));
         $this->assertEquals(200, $exceptions[0]->getCode());
     }
+
+    public function testHeaderNamesAreCaseInsensitive()
+    {
+        $this->_response->setHeader('X-Foo_Bar-Baz', 'value');
+        $this->_response->setHeader('X-FOO_bar-bAz', 'bat');
+
+        $headers = $this->_response->getHeaders();
+        $names   = array();
+        foreach ($headers as $header) {
+            $names[] = $header['name'];
+        }
+        $this->assertTrue(in_array('X-Foo-Bar-Baz', $names), var_export($headers, 1));
+        $this->assertFalse(in_array('X-Foo_Bar-Baz', $names));
+        $this->assertFalse(in_array('X-FOO_bar-bAz', $names));
+    }
 }
 
 require_once 'Zend/Controller/Action.php';
-class Zend_Controller_Response_HttpTest_Action extends Zend_Controller_Action 
+class Zend_Controller_Response_HttpTest_Action extends Zend_Controller_Action
 {}
 
 // Call Zend_Controller_Response_HttpTest::main() if this source file is executed directly.
