@@ -5,7 +5,10 @@
  * @subpackage UnitTests
  */
 
-/** Zend_Controller_Router_Route */
+/** @see Zend_Controller_Request_Http */
+require_once 'Zend/Controller/Request/Http.php';
+
+/** @see Zend_Controller_Router_Route */
 require_once 'Zend/Controller/Router/Route.php';
 
 /** PHPUnit test case */
@@ -18,6 +21,38 @@ require_once 'PHPUnit/Framework/TestCase.php';
  */
 class Zend_Controller_Router_RouteTest extends PHPUnit_Framework_TestCase
 {
+    /**
+     * Server backup
+     *
+     * @var array
+     */
+    protected $_server = array();
+
+    /**
+     * Setup test
+     *
+     * @return void
+     */
+    public function setUp()
+    {
+        // Backup server array
+        $this->_server = $_SERVER;
+
+        // Clean host env
+        unset($_SERVER['HTTP_HOST'],
+            $_SERVER['HTTPS'], $_SERVER['SERVER_NAME'], $_SERVER['SERVER_PORT']);
+    }
+
+    /**
+     * Clean
+     *
+     * @return void
+     */
+    public function tearDown()
+    {
+        // Restore server array
+        $_SERVER = $this->_server;
+    }
 
     public function testStaticMatch()
     {
@@ -56,7 +91,7 @@ class Zend_Controller_Router_RouteTest extends PHPUnit_Framework_TestCase
         $route = new Zend_Controller_Router_Route('users/a');
         $values = $route->match('users/a/martel');
 
-        $this->assertSame(false, $values);
+        $this->assertEquals(false, $values);
     }
 
     public function testStaticMatchWithDefaults()
@@ -64,32 +99,32 @@ class Zend_Controller_Router_RouteTest extends PHPUnit_Framework_TestCase
         $route = new Zend_Controller_Router_Route('users/all', array('controller' => 'ctrl'));
         $values = $route->match('users/all');
 
-        $this->assertSame('ctrl', $values['controller']);
+        $this->assertEquals('ctrl', $values['controller']);
     }
 
     public function testNotMatched()
     {
         $route = new Zend_Controller_Router_Route('users/all');
         $values = $route->match('users/martel');
-        
-        $this->assertSame(false, $values);
+
+        $this->assertEquals(false, $values);
     }
-    
+
     public function testNotMatchedWithVariablesAndDefaults()
     {
         $route = new Zend_Controller_Router_Route(':controller/:action', array('controller' => 'index', 'action' => 'index'));
         $values = $route->match('archive/action/bogus');
-        
-        $this->assertSame(false, $values);
+
+        $this->assertEquals(false, $values);
     }
-    
-    
-    public function testNotMatchedWithVariablesAndStatic() 
+
+
+    public function testNotMatchedWithVariablesAndStatic()
     {
         $route = new Zend_Controller_Router_Route('archive/:year/:month');
         $values = $route->match('ctrl/act/2000');
 
-        $this->assertSame(false, $values);
+        $this->assertEquals(false, $values);
     }
 
     public function testStaticMatchWithWildcard()
@@ -108,7 +143,7 @@ class Zend_Controller_Router_RouteTest extends PHPUnit_Framework_TestCase
     {
         $route = new Zend_Controller_Router_Route('news/*', array('controller' => 'news', 'action' => 'view'));
         $values = $route->match('news/klucz/wartość/wskaźnik/wartość');
-        
+
         $this->assertEquals('news', $values['controller']);
         $this->assertEquals('view', $values['action']);
         $this->assertEquals('wartość', $values['klucz']);
@@ -119,7 +154,7 @@ class Zend_Controller_Router_RouteTest extends PHPUnit_Framework_TestCase
     {
         $route = new Zend_Controller_Router_Route('news/*', array('controller' => 'news', 'action' => 'view'));
         $values = $route->match('news/wska%C5%BAnik/warto%C5%9B%C4%87');
-        
+
         $this->assertEquals('news', $values['controller']);
         $this->assertEquals('view', $values['action']);
         $this->assertEquals('wartość', $values['wskaźnik']);
@@ -130,9 +165,9 @@ class Zend_Controller_Router_RouteTest extends PHPUnit_Framework_TestCase
         $route = new Zend_Controller_Router_Route(':controller/:action/:year');
         $values = $route->match('ctrl/act/2000');
 
-        $this->assertSame('ctrl', $values['controller']);
-        $this->assertSame('act', $values['action']);
-        $this->assertSame('2000', $values['year']);
+        $this->assertEquals('ctrl', $values['controller']);
+        $this->assertEquals('act', $values['action']);
+        $this->assertEquals('2000', $values['year']);
     }
 
     public function testVariableUTFValues()
@@ -140,7 +175,7 @@ class Zend_Controller_Router_RouteTest extends PHPUnit_Framework_TestCase
         $route = new Zend_Controller_Router_Route('test/:param');
         $values = $route->match('test/aä');
 
-        $this->assertSame('aä', $values['param']);
+        $this->assertEquals('aä', $values['param']);
     }
 
     public function testOneVariableValue()
@@ -148,8 +183,8 @@ class Zend_Controller_Router_RouteTest extends PHPUnit_Framework_TestCase
         $route = new Zend_Controller_Router_Route(':action', array('controller' => 'ctrl', 'action' => 'action'));
         $values = $route->match('act');
 
-        $this->assertSame('ctrl', $values['controller']);
-        $this->assertSame('act', $values['action']);
+        $this->assertEquals('ctrl', $values['controller']);
+        $this->assertEquals('act', $values['action']);
     }
 
     public function testVariablesWithDefault()
@@ -157,9 +192,9 @@ class Zend_Controller_Router_RouteTest extends PHPUnit_Framework_TestCase
         $route = new Zend_Controller_Router_Route(':controller/:action/:year', array('year' => '2006'));
         $values = $route->match('ctrl/act');
 
-        $this->assertSame('ctrl', $values['controller']);
-        $this->assertSame('act', $values['action']);
-        $this->assertSame('2006', $values['year']);
+        $this->assertEquals('ctrl', $values['controller']);
+        $this->assertEquals('act', $values['action']);
+        $this->assertEquals('2006', $values['year']);
     }
 
     public function testVariablesWithNullDefault() // Kevin McArthur
@@ -167,19 +202,19 @@ class Zend_Controller_Router_RouteTest extends PHPUnit_Framework_TestCase
         $route = new Zend_Controller_Router_Route(':controller/:action/:year', array('year' => null));
         $values = $route->match('ctrl/act');
 
-        $this->assertSame('ctrl', $values['controller']);
-        $this->assertSame('act', $values['action']);
+        $this->assertEquals('ctrl', $values['controller']);
+        $this->assertEquals('act', $values['action']);
         $this->assertNull($values['year']);
     }
-    
+
     public function testVariablesWithDefaultAndValue()
     {
         $route = new Zend_Controller_Router_Route(':controller/:action/:year', array('year' => '2006'));
         $values = $route->match('ctrl/act/2000');
 
-        $this->assertSame('ctrl', $values['controller']);
-        $this->assertSame('act', $values['action']);
-        $this->assertSame('2000', $values['year']);
+        $this->assertEquals('ctrl', $values['controller']);
+        $this->assertEquals('act', $values['action']);
+        $this->assertEquals('2000', $values['year']);
     }
 
     public function testVariablesWithRequirementAndValue()
@@ -187,9 +222,9 @@ class Zend_Controller_Router_RouteTest extends PHPUnit_Framework_TestCase
         $route = new Zend_Controller_Router_Route(':controller/:action/:year', null, array('year' => '\d+'));
         $values = $route->match('ctrl/act/2000');
 
-        $this->assertSame('ctrl', $values['controller']);
-        $this->assertSame('act', $values['action']);
-        $this->assertSame('2000', $values['year']);
+        $this->assertEquals('ctrl', $values['controller']);
+        $this->assertEquals('act', $values['action']);
+        $this->assertEquals('2000', $values['year']);
     }
 
     public function testVariablesWithRequirementAndIncorrectValue()
@@ -197,7 +232,7 @@ class Zend_Controller_Router_RouteTest extends PHPUnit_Framework_TestCase
         $route = new Zend_Controller_Router_Route(':controller/:action/:year', null, array('year' => '\d+'));
         $values = $route->match('ctrl/act/2000t');
 
-        $this->assertSame(false, $values);
+        $this->assertEquals(false, $values);
     }
 
     public function testVariablesWithDefaultAndRequirement()
@@ -205,9 +240,9 @@ class Zend_Controller_Router_RouteTest extends PHPUnit_Framework_TestCase
         $route = new Zend_Controller_Router_Route(':controller/:action/:year', array('year' => '2006'), array('year' => '\d+'));
         $values = $route->match('ctrl/act/2000');
 
-        $this->assertSame('ctrl', $values['controller']);
-        $this->assertSame('act', $values['action']);
-        $this->assertSame('2000', $values['year']);
+        $this->assertEquals('ctrl', $values['controller']);
+        $this->assertEquals('act', $values['action']);
+        $this->assertEquals('2000', $values['year']);
     }
 
     public function testVariablesWithDefaultAndRequirementAndIncorrectValue()
@@ -215,7 +250,7 @@ class Zend_Controller_Router_RouteTest extends PHPUnit_Framework_TestCase
         $route = new Zend_Controller_Router_Route(':controller/:action/:year', array('year' => '2006'), array('year' => '\d+'));
         $values = $route->match('ctrl/act/2000t');
 
-        $this->assertSame(false, $values);
+        $this->assertEquals(false, $values);
     }
 
     public function testVariablesWithDefaultAndRequirementAndWithoutValue()
@@ -223,9 +258,9 @@ class Zend_Controller_Router_RouteTest extends PHPUnit_Framework_TestCase
         $route = new Zend_Controller_Router_Route(':controller/:action/:year', array('year' => '2006'), array('year' => '\d+'));
         $values = $route->match('ctrl/act');
 
-        $this->assertSame('ctrl', $values['controller']);
-        $this->assertSame('act', $values['action']);
-        $this->assertSame('2006', $values['year']);
+        $this->assertEquals('ctrl', $values['controller']);
+        $this->assertEquals('act', $values['action']);
+        $this->assertEquals('2006', $values['year']);
     }
 
     public function testVariablesWithWildcardAndNumericKey()
@@ -233,9 +268,9 @@ class Zend_Controller_Router_RouteTest extends PHPUnit_Framework_TestCase
         $route = new Zend_Controller_Router_Route(':controller/:action/:next/*');
         $values = $route->match('c/a/next/2000/show/all/sort/name');
 
-        $this->assertSame('c', $values['controller']);
-        $this->assertSame('a', $values['action']);
-        $this->assertSame('next', $values['next']);
+        $this->assertEquals('c', $values['controller']);
+        $this->assertEquals('a', $values['action']);
+        $this->assertEquals('next', $values['next']);
         $this->assertTrue(array_key_exists('2000', $values));
     }
 
@@ -244,7 +279,7 @@ class Zend_Controller_Router_RouteTest extends PHPUnit_Framework_TestCase
         $route = new Zend_Controller_Router_Route('/');
         $values = $route->match('');
 
-        $this->assertSame(array(), $values);
+        $this->assertEquals(array(), $values);
     }
 
     public function testAssemble()
@@ -252,14 +287,14 @@ class Zend_Controller_Router_RouteTest extends PHPUnit_Framework_TestCase
         $route = new Zend_Controller_Router_Route('authors/:name');
         $url = $route->assemble(array('name' => 'martel'));
 
-        $this->assertSame('authors/martel', $url);
+        $this->assertEquals('authors/martel', $url);
     }
 
     public function testAssembleWithoutValue()
     {
         $route = new Zend_Controller_Router_Route('authors/:name');
         try {
-            $url = $route->assemble();   
+            $url = $route->assemble();
         } catch (Exception $e) {
             return true;
         }
@@ -272,7 +307,7 @@ class Zend_Controller_Router_RouteTest extends PHPUnit_Framework_TestCase
         $route = new Zend_Controller_Router_Route('authors/:name', array('name' => 'martel'));
         $url = $route->assemble();
 
-        $this->assertSame('authors', $url);
+        $this->assertEquals('authors', $url);
     }
 
     public function testAssembleWithDefaultAndValue()
@@ -280,7 +315,7 @@ class Zend_Controller_Router_RouteTest extends PHPUnit_Framework_TestCase
         $route = new Zend_Controller_Router_Route('authors/:name', array('name' => 'martel'));
         $url = $route->assemble(array('name' => 'mike'));
 
-        $this->assertSame('authors/mike', $url);
+        $this->assertEquals('authors/mike', $url);
     }
 
     public function testAssembleWithWildcardMap()
@@ -288,7 +323,7 @@ class Zend_Controller_Router_RouteTest extends PHPUnit_Framework_TestCase
         $route = new Zend_Controller_Router_Route('authors/:name/*');
         $url = $route->assemble(array('name' => 'martel'));
 
-        $this->assertSame('authors/martel', $url);
+        $this->assertEquals('authors/martel', $url);
     }
 
     public function testAssembleWithReset()
@@ -298,9 +333,9 @@ class Zend_Controller_Router_RouteTest extends PHPUnit_Framework_TestCase
 
         $url = $route->assemble(array('year' => '2005'), true);
 
-        $this->assertSame('archive/2005', $url);
+        $this->assertEquals('archive/2005', $url);
     }
-    
+
     public function testAssembleWithReset2()
     {
         $route = new Zend_Controller_Router_Route(':controller/:action/*', array('controller' => 'archive', 'action' => 'show'));
@@ -308,9 +343,9 @@ class Zend_Controller_Router_RouteTest extends PHPUnit_Framework_TestCase
 
         $url = $route->assemble(array(), true);
 
-        $this->assertSame('', $url);
+        $this->assertEquals('', $url);
     }
-    
+
     public function testAssembleWithReset3()
     {
         $route = new Zend_Controller_Router_Route('archive/:year/*', array('controller' => 'archive', 'action' => 'show', 'year' => 2005));
@@ -318,9 +353,9 @@ class Zend_Controller_Router_RouteTest extends PHPUnit_Framework_TestCase
 
         $url = $route->assemble(array(), true);
 
-        $this->assertSame('archive', $url);
+        $this->assertEquals('archive', $url);
     }
-    
+
     public function testAssembleWithReset4()
     {
         $route = new Zend_Controller_Router_Route(':controller/:action/*', array('controller' => 'archive', 'action' => 'show'));
@@ -328,7 +363,7 @@ class Zend_Controller_Router_RouteTest extends PHPUnit_Framework_TestCase
 
         $url = $route->assemble(array('action' => 'display'), true);
 
-        $this->assertSame('archive/display', $url);
+        $this->assertEquals('archive/display', $url);
     }
 
     public function testAssembleWithReset5()
@@ -337,16 +372,16 @@ class Zend_Controller_Router_RouteTest extends PHPUnit_Framework_TestCase
         $values = $route->match('key1/value1/key2/value2');
 
         $url = $route->assemble(array('key1' => 'newvalue'), true);
-        
-        $this->assertSame('key1/newvalue', $url);
+
+        $this->assertEquals('key1/newvalue', $url);
     }
-    
+
     public function testAssembleWithWildcardAndAdditionalParameters()
     {
         $route = new Zend_Controller_Router_Route('authors/:name/*');
         $url = $route->assemble(array('name' => 'martel', 'var' => 'value'));
 
-        $this->assertSame('authors/martel/var/value', $url);
+        $this->assertEquals('authors/martel/var/value', $url);
     }
 
     public function testAssembleWithUrlVariablesReuse()
@@ -354,9 +389,9 @@ class Zend_Controller_Router_RouteTest extends PHPUnit_Framework_TestCase
         $route = new Zend_Controller_Router_Route('archives/:year/:month');
         $values = $route->match('archives/2006/07');
         $this->assertType('array', $values);
-        
+
         $url = $route->assemble(array('month' => '03'));
-        $this->assertSame('archives/2006/03', $url);
+        $this->assertEquals('archives/2006/03', $url);
     }
 
     public function testWildcardUrlVariablesOverwriting()
@@ -364,32 +399,32 @@ class Zend_Controller_Router_RouteTest extends PHPUnit_Framework_TestCase
         $route = new Zend_Controller_Router_Route('archives/:year/:month/*', array('controller' => 'archive'));
         $values = $route->match('archives/2006/07/controller/test/year/10000/sort/author');
         $this->assertType('array', $values);
-        
-        $this->assertSame('archive', $values['controller']);
-        $this->assertSame('2006', $values['year']);
-        $this->assertSame('07', $values['month']);
-        $this->assertSame('author', $values['sort']);
+
+        $this->assertEquals('archive', $values['controller']);
+        $this->assertEquals('2006', $values['year']);
+        $this->assertEquals('07', $values['month']);
+        $this->assertEquals('author', $values['sort']);
     }
-    
+
     public function testGetDefaults()
     {
-        $route = new Zend_Controller_Router_Route('users/all', 
+        $route = new Zend_Controller_Router_Route('users/all',
                     array('controller' => 'ctrl', 'action' => 'act'));
 
         $values = $route->getDefaults();
 
         $this->assertType('array', $values);
-        $this->assertSame('ctrl', $values['controller']);
-        $this->assertSame('act', $values['action']);
+        $this->assertEquals('ctrl', $values['controller']);
+        $this->assertEquals('act', $values['action']);
     }
 
     public function testGetDefault()
     {
-        $route = new Zend_Controller_Router_Route('users/all', 
+        $route = new Zend_Controller_Router_Route('users/all',
                     array('controller' => 'ctrl', 'action' => 'act'));
 
-        $this->assertSame('ctrl', $route->getDefault('controller'));
-        $this->assertSame(null, $route->getDefault('bogus'));
+        $this->assertEquals('ctrl', $route->getDefault('controller'));
+        $this->assertEquals(null, $route->getDefault('bogus'));
     }
 
     public function testGetInstance()
@@ -402,71 +437,155 @@ class Zend_Controller_Router_RouteTest extends PHPUnit_Framework_TestCase
                 'controller' => 'ctrl'
             )
         );
-        
+
         $config = new Zend_Config($routeConf);
         $route = Zend_Controller_Router_Route::getInstance($config);
-        
+
         $this->assertType('Zend_Controller_Router_Route', $route);
 
         $values = $route->match('users/all');
 
-        $this->assertSame('ctrl', $values['controller']);
+        $this->assertEquals('ctrl', $values['controller']);
 
     }
 
     public function testAssembleResetDefaults()
-    {    
+    {
         $route = new Zend_Controller_Router_Route(':controller/:action/*', array('controller' => 'index', 'action' => 'index'));
-        
+
         $values = $route->match('news/view/id/3');
 
+        $url = $route->assemble(array('controller' => null));
+        $this->assertEquals('index/view/id/3', $url);
+
         $url = $route->assemble(array('action' => null));
-        $this->assertSame('news/index/id/3', $url);
+        $this->assertEquals('news/index/id/3', $url);
 
         $url = $route->assemble(array('action' => null, 'id' => null));
-        $this->assertSame('news', $url);
+        $this->assertEquals('news', $url);
     }
 
     public function testAssembleWithRemovedDefaults() // Test for ZF-1197
-    {    
+    {
         $route = new Zend_Controller_Router_Route(':controller/:action/*', array('controller' => 'index', 'action' => 'index'));
-        
+
         $url = $route->assemble(array('id' => 3));
-        $this->assertSame('index/index/id/3', $url);
+        $this->assertEquals('index/index/id/3', $url);
 
         $url = $route->assemble(array('action' => 'test'));
-        $this->assertSame('index/test', $url);
+        $this->assertEquals('index/test', $url);
 
         $url = $route->assemble(array('action' => 'test', 'id' => 3));
-        $this->assertSame('index/test/id/3', $url);
+        $this->assertEquals('index/test/id/3', $url);
 
         $url = $route->assemble(array('controller' => 'test'));
-        $this->assertSame('test', $url);
+        $this->assertEquals('test', $url);
 
         $url = $route->assemble(array('controller' => 'test', 'action' => 'test'));
-        $this->assertSame('test/test', $url);
+        $this->assertEquals('test/test', $url);
 
         $url = $route->assemble(array('controller' => 'test', 'id' => 3));
-        $this->assertSame('test/index/id/3', $url);
+        $this->assertEquals('test/index/id/3', $url);
 
         $url = $route->assemble(array());
-        $this->assertSame('', $url);
+        $this->assertEquals('', $url);
 
         $route->match('ctrl');
 
         $url = $route->assemble(array('id' => 3));
-        $this->assertSame('ctrl/index/id/3', $url);
+        $this->assertEquals('ctrl/index/id/3', $url);
 
         $url = $route->assemble(array('action' => 'test'));
-        $this->assertSame('ctrl/test', $url);
+        $this->assertEquals('ctrl/test', $url);
 
         $url = $route->assemble();
-        $this->assertSame('ctrl', $url);
-        
+        $this->assertEquals('ctrl', $url);
+
         $route->match('index');
-        
+
         $url = $route->assemble();
-        $this->assertSame('', $url);
+        $this->assertEquals('', $url);
     }
 
+    /**
+     * Test guarding performance. Test may be failing on slow systems and shouldn't be failing on production.
+     * This test is not critical in nature - it allows keeping changes performant.
+     */
+    public function testRoutePerformance()
+    {
+        $count = 10000;
+        $expectedTime = 1;
+
+        $info = "This test may be failing on slow systems and shouldn't be failing on production. Tests if " . ($count / 10) . " complicated routes can be matched in a tenth of a second. Actual test matches " . $count . " times to make the test more reliable.";
+
+        $route = new Zend_Controller_Router_Route('archives/:year/:month/*', array('controller' => 'archive'));
+
+        $time_start = microtime(true);
+
+        for ($i = 1; $i <= $count; $i++) {
+            $values = $route->match('archives/2006/' . $i . '/controller/test/year/' . $i . '/sort/author');
+        }
+
+        $time_end = microtime(true);
+        $time = $time_end - $time_start;
+
+        $this->assertLessThan($expectedTime, $time, $info);
+    }
+
+    public function testForZF2543()
+    {
+        $route = new Zend_Controller_Router_Route('families/:action/*', array('module' => 'default', 'controller' => 'categories', 'action' => 'index'));
+        $this->assertEquals('families', $route->assemble());
+
+        $values = $route->match('families/edit/id/4');
+        $this->assertType('array', $values);
+
+        $this->assertEquals('families/edit/id/4', $route->assemble());
+    }
+
+    public function testEncode()
+    {
+        $route = new Zend_Controller_Router_Route(':controller/:action/*', array('controller' => 'index', 'action' => 'index'));
+
+        $url = $route->assemble(array('controller' => 'My Controller'), false, true);
+        $this->assertEquals('My+Controller', $url);
+
+        $url = $route->assemble(array('controller' => 'My Controller'), false, false);
+        $this->assertEquals('My Controller', $url);
+
+        $token = $route->match('en/foo/id/My Value');
+
+        $url = $route->assemble(array(), false, true);
+        $this->assertEquals('en/foo/id/My+Value', $url);
+
+        $url = $route->assemble(array('id' => 'My Other Value'), false, true);
+        $this->assertEquals('en/foo/id/My+Other+Value', $url);
+
+        $route = new Zend_Controller_Router_Route(':controller/*', array('controller' => 'My Controller'));
+        $url = $route->assemble(array('id' => 1), false, true);
+        $this->assertEquals('My+Controller/id/1', $url);
+    }
+    
+    public function testPartialMatch()
+    {
+        $this->markTestSkipped('Route features not ready');
+        
+        $route = new Zend_Controller_Router_Route(':lang/:temp', array('lang' => 'pl'), array('temp' => '\d+'));
+
+        $values = $route->match('en/tmp/ctrl/action/id/1', true);
+
+        $this->assertFalse($values);
+        
+        $route = new Zend_Controller_Router_Route(':lang/:temp', array('lang' => 'pl'));
+
+        $values = $route->match('en/tmp/ctrl/action/id/1', true);
+
+        $this->assertType('array', $values);
+        $this->assertEquals('en', $values['lang']);
+        $this->assertEquals('tmp', $values['temp']);
+        $this->assertEquals(6, $values[null]);
+        
+    }
+    
+
 }
