@@ -16,9 +16,9 @@
  * @category   Zend
  * @package    Zend_Db
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2007 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: TestCommon.php 6289 2007-09-11 01:21:38Z bkarwin $
+ * @version    $Id: TestCommon.php 6923 2007-11-25 02:00:06Z peptolab $
  */
 
 
@@ -40,11 +40,57 @@ PHPUnit_Util_Filter::addFileToFilter(__FILE__);
  * @category   Zend
  * @package    Zend_Db
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2007 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 abstract class Zend_Db_Adapter_TestCommon extends Zend_Db_TestSetup
 {
+    /**
+     * Test AUTO_QUOTE_IDENTIFIERS option
+     * Case: Zend_Db::AUTO_QUOTE_IDENTIFIERS = true
+     */
+    public function testAdapterZendConfig()
+    {
+        Zend_Loader::loadClass('Zend_Config');
+        $params = new Zend_Config($this->_util->getParams());
+
+        $db = Zend_Db::factory($this->getDriver(), $params);
+        $db->getConnection();
+    }
+
+    /**
+     * Test empty adapterNamespace issue
+     * Case: Zend_Db::AUTO_QUOTE_IDENTIFIERS = true
+     */
+    public function testAdapterZendConfigEmptyNamespace()
+    {
+        Zend_Loader::loadClass('Zend_Config');
+        $params = $this->_util->getParams();
+        $params['adapterNamespace'] = '';
+        $params = new Zend_Config($params);
+
+        $db = Zend_Db::factory($this->getDriver(), $params);
+        $db->getConnection();
+    }
+
+    /**
+     * Test empty driver_options issue
+     * Case: $config['driver_options'] == ''
+     */
+    public function testAdapterZendConfigEmptyDriverOptions()
+    {
+        Zend_Loader::loadClass('Zend_Config');
+        $params = $this->_util->getParams();
+        $params['driver_options'] = '';
+        $params = new Zend_Config($params);
+
+        $db = Zend_Db::factory($this->getDriver(), $params);
+        $db->getConnection();
+
+        $config = $db->getConfig();
+        $this->assertEquals(array(), $config['driver_options']);
+    }
+
     /**
      * Test AUTO_QUOTE_IDENTIFIERS option
      * Case: Zend_Db::AUTO_QUOTE_IDENTIFIERS = true
@@ -125,7 +171,7 @@ abstract class Zend_Db_Adapter_TestCommon extends Zend_Db_TestSetup
             'result of first query not as expected');
 
         // insert into the table using other case
-        $numRows = $db->insert(strtoupper($tableName), array(
+        $numRows = $db->insert($tableName, array(
             'ID'    => 2,
             'STUFF' => 'no quote 2'
         ));
@@ -133,7 +179,7 @@ abstract class Zend_Db_Adapter_TestCommon extends Zend_Db_TestSetup
             'number of rows in second insert not as expected');
 
         // check if the row was inserted as expected
-        $sql = 'SELECT ID, STUFF FROM '.strtoupper($tableName).' ORDER BY ID';
+        $sql = 'SELECT ID, STUFF FROM ' . $tableName . ' ORDER BY ID';
         $stmt = $db->query($sql);
         $fetched = $stmt->fetchAll(Zend_Db::FETCH_NUM);
 
@@ -369,6 +415,40 @@ abstract class Zend_Db_Adapter_TestCommon extends Zend_Db_TestSetup
         $this->assertEquals('2', $result[0]['product_id']);
     }
 
+    /**
+     * Test that fetchAssoc() still fetched an associative array
+     * after the adapter's default fetch mode is set to something else.
+     */
+    public function testAdapterFetchAllOverrideFetchMode()
+    {
+        $products = $this->_db->quoteIdentifier('zfproducts');
+        $product_id = $this->_db->quoteIdentifier('product_id');
+        $col_name = $this->_db->foldCase('product_id');
+
+        $this->_db->setFetchMode(Zend_Db::FETCH_OBJ);
+
+        // Test associative array
+        $result = $this->_db->fetchAll("SELECT * FROM $products WHERE $product_id > ? ORDER BY $product_id ASC", 1, Zend_Db::FETCH_ASSOC);
+        $this->assertEquals(2, count($result));
+        $this->assertType('array', $result[0]);
+        $this->assertEquals(2, count($result[0])); // count columns
+        $this->assertEquals(2, $result[0][$col_name]);
+
+        // Test numeric and associative array
+        $result = $this->_db->fetchAll("SELECT * FROM $products WHERE $product_id > ? ORDER BY $product_id ASC", 1, Zend_Db::FETCH_BOTH);
+        $this->assertEquals(2, count($result));
+        $this->assertType('array', $result[0]);
+        $this->assertEquals(4, count($result[0])); // count columns
+        $this->assertEquals(2, $result[0][$col_name]);
+        $this->assertEquals(2, $result[0][0]);
+
+        // Ensure original fetch mode has been retained
+        $result = $this->_db->fetchAll("SELECT * FROM $products WHERE $product_id > ? ORDER BY $product_id", 1);
+        $this->assertEquals(2, count($result));
+        $this->assertType('object', $result[0]);
+        $this->assertEquals(2, $result[0]->$col_name);
+    }
+
     /**
      * Test the Adapter's fetchAssoc() method.
      */
@@ -506,6 +586,37 @@ abstract class Zend_Db_Adapter_TestCommon extends Zend_Db_TestSetup
         $this->assertEquals(2, $result['product_id']);
     }
 
+    /**
+     * Test that fetchAssoc() still fetched an associative array
+     * after the adapter's default fetch mode is set to something else.
+     */
+    public function testAdapterFetchRowOverrideFetchMode()
+    {
+        $products = $this->_db->quoteIdentifier('zfproducts');
+        $product_id = $this->_db->quoteIdentifier('product_id');
+        $col_name = $this->_db->foldCase('product_id');
+
+        $this->_db->setFetchMode(Zend_Db::FETCH_OBJ);
+
+        // Test associative array
+        $result = $this->_db->fetchRow("SELECT * FROM $products WHERE $product_id > ? ORDER BY $product_id", 1, Zend_Db::FETCH_ASSOC);
+        $this->assertType('array', $result);
+        $this->assertEquals(2, count($result)); // count columns
+        $this->assertEquals(2, $result['product_id']);
+
+        // Test numeric and associative array
+        $result = $this->_db->fetchRow("SELECT * FROM $products WHERE $product_id > ? ORDER BY $product_id", 1, Zend_Db::FETCH_BOTH);
+        $this->assertType('array', $result);
+        $this->assertEquals(4, count($result)); // count columns
+        $this->assertEquals(2, $result['product_id']);
+        $this->assertEquals(2, $result[0]);
+
+        // Ensure original fetch mode has been retained
+        $result = $this->_db->fetchRow("SELECT * FROM $products WHERE $product_id > ? ORDER BY $product_id", 1);
+        $this->assertType('object', $result);
+        $this->assertEquals(2, $result->$col_name);
+    }
+
     /**
      * Test the Adapter's insert() method.
      * This requires providing an associative array of column=>value pairs.
@@ -1091,7 +1202,7 @@ abstract class Zend_Db_Adapter_TestCommon extends Zend_Db_TestSetup
 
         $value = $this->_db->quoteInto('foo = ?', 12.34, Zend_Db::FLOAT_TYPE);
         $this->assertType('string', $value);
-        $this->assertEquals('foo = 12.34', $value,
+        $this->assertEquals('foo = 12.340000', $value,
             'Incorrect quoteInto() result for FLOAT_TYPE');
 
         $value = $this->_db->quoteInto('foo = ?', 1234, 'CHAR');
@@ -1105,6 +1216,14 @@ abstract class Zend_Db_Adapter_TestCommon extends Zend_Db_TestSetup
             'Incorrect quoteInto() result for CHAR');
     }
 
+    public function testAdapterQuoteIntoCount() 
+    { 
+        $value = $this->_db->quoteInto('foo = ? and bar = ?', 1234, null, 1); 
+        $this->assertType('string', $value); 
+        $this->assertEquals('foo = 1234 and bar = ?', $value, 
+            'Incorrect quoteInto() result for count'); 
+    } 
+
     public function testAdapterQuoteTypeInt()
     {
         foreach ($this->_numericDataTypes as $typeName => $type) {
@@ -1315,6 +1434,21 @@ abstract class Zend_Db_Adapter_TestCommon extends Zend_Db_TestSetup
             "Incorrect quote() CHAR type result for Zend_Db_Expr");
     }
 
+    /**
+     * Ensures that the character sequence ":0'" is handled properly
+     *
+     * @link   http://framework.zend.com/issues/browse/ZF-2059
+     * @return void
+     */
+    public function testZF2059()
+    {
+        $value       = ':0\'';
+        $valueQuoted = $this->_db->quote($value);
+        $sql = 'SELECT bug_id FROM zfbugs WHERE bug_status != ' . $valueQuoted;
+        $results = $this->_db->fetchAll($sql);
+        $this->assertEquals(4, count($results));
+    }
+
     public function testAdapterSetFetchMode()
     {
         $modes = array(
@@ -1582,4 +1716,48 @@ abstract class Zend_Db_Adapter_TestCommon extends Zend_Db_TestSetup
         $this->assertEquals(array_fill(0, 4, 'EMPTY'), $value);
     }
 
-}
+    protected function _testAdapterAlternateStatement($stmtClass)
+    {
+        $ip = get_include_path();
+        $dir = dirname(__FILE__) . DIRECTORY_SEPARATOR . '_files';
+        $newIp = $dir . PATH_SEPARATOR . $ip;
+        set_include_path($newIp);
+
+        $params = $this->_util->getParams();
+
+        $params['options'] = array(
+            Zend_Db::AUTO_QUOTE_IDENTIFIERS => false
+        );
+        $db = Zend_Db::factory($this->getDriver(), $params);
+        $db->getConnection();
+        $db->setStatementClass($stmtClass);
+
+        $currentStmtClass = $db->getStatementClass();
+        $this->assertEquals($stmtClass, $currentStmtClass);
+
+        $bugs = $this->_db->quoteIdentifier('zfbugs');
+
+        $stmt = $db->prepare("SELECT COUNT(*) FROM $bugs");
+
+        $this->assertType($stmtClass, $stmt,
+            'Expecting object of type ' . $stmtClass . ', got ' . get_class($stmt));
+    }
+
+    public function testAdapterSetCustomProfiler()
+    {
+        $profilerOptions = array(
+            'enabled'  => true,
+            'class'    => 'stdClass',
+            'instance' => new stdClass()
+        );
+
+        try {
+            $this->_db->setProfiler($profilerOptions);
+            $this->fail('Expected to catch Zend_Db_Profiler_Exception');
+        } catch (Zend_Exception $e) {
+            $this->assertType('Zend_Db_Profiler_Exception', $e);
+            $this->assertEquals('Class stdClass does not extend Zend_Db_Profiler', $e->getMessage());
+        }
+    }
+
+}
\ No newline at end of file
