@@ -16,9 +16,9 @@
  * @category   Zend
  * @package    Zend_Db
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2007 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: StaticTest.php 6896 2007-11-22 08:19:59Z thomas $
+ * @version    $Id: StaticTest.php 7508 2008-01-19 03:12:38Z peptolab $
  */
 
 
@@ -35,7 +35,7 @@ PHPUnit_Util_Filter::addFileToFilter(__FILE__);
  * @category   Zend
  * @package    Zend_Db
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2007 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 class Zend_Db_Select_StaticTest extends Zend_Db_Select_TestCommon
@@ -154,14 +154,6 @@ class Zend_Db_Select_StaticTest extends Zend_Db_Select_TestCommon
         $this->assertEquals('SELECT DISTINCT 327 FROM "zfproducts"', $sql);
     }
 
-    /**
-     * Test adding the FOR UPDATE query modifier to a Zend_Db_Select object.
-     *
-    public function testSelectForUpdateModifier()
-    {
-    }
-     */
-
     /**
      * Test support for schema-qualified table names in from()
      * e.g. from('schema.table').
@@ -174,6 +166,24 @@ class Zend_Db_Select_StaticTest extends Zend_Db_Select_TestCommon
         $this->assertEquals('SELECT "zfproducts".* FROM "dummy"."zfproducts"', $sql);
     }
 
+    public function testSelectColumnsReset()
+    {
+        $select = $this->_selectColumnsReset()
+            ->reset(Zend_Db_Select::COLUMNS)
+            ->columns('product_name');
+        $sql = preg_replace('/\\s+/', ' ', $select->__toString());
+        $this->assertEquals('SELECT "p"."product_name" FROM "zfproducts" AS "p"', $sql);
+    }
+
+    public function testSelectFromForUpdate()
+    {
+        $select = $this->_db->select()
+            ->from("zfproducts")
+            ->forUpdate();
+        $sql = preg_replace('/\\s+/', ' ', $select->__toString());
+        $this->assertEquals('SELECT "zfproducts".* FROM "zfproducts" FOR UPDATE', $sql);
+    }
+
     /**
      * Test adding a JOIN to a Zend_Db_Select object.
      */
@@ -254,6 +264,35 @@ class Zend_Db_Select_StaticTest extends Zend_Db_Select_TestCommon
         $this->assertEquals('SELECT "zfproducts".*, "zfbugs_products".* FROM "zfproducts" INNER JOIN "dummy"."zfbugs_products" ON "zfproducts"."product_id" = "zfbugs_products"."product_id"', $sql);
     }
 
+    /**
+     * Test adding a JOIN USING to a Zend_Db_Select object.
+     */
+
+    public function testSelectJoinUsing()
+    {
+        $select = $this->_selectJoinUsing();
+        $sql = preg_replace('/\\s+/', ' ', $select->__toString());
+        $this->assertEquals('SELECT "zfproducts".*, "zfbugs_products".* FROM "zfproducts" INNER JOIN "zfbugs_products" ON "zfbugs_products"."product_id" = "zfproducts"."product_id" WHERE ("zfbugs_products"."product_id" < 3)', $sql);
+    }
+
+    /**
+     * Test adding a JOIN INNER USING to a Zend_Db_Select object.
+     */
+
+    public function testSelectJoinInnerUsing()
+    {
+        $select = $this->_selectJoinInnerUsing();
+        $sql = preg_replace('/\\s+/', ' ', $select->__toString());
+        $this->assertEquals('SELECT "zfproducts".*, "zfbugs_products".* FROM "zfproducts" INNER JOIN "zfbugs_products" ON "zfbugs_products"."product_id" = "zfproducts"."product_id" WHERE ("zfbugs_products"."product_id" < 3)', $sql);
+    }
+
+    public function testSelectJoinWithNocolumns()
+    {
+        $select = $this->_selectJoinWithNocolumns();
+        $sql = preg_replace('/\\s+/', ' ', $select->__toString());
+        $this->assertEquals('SELECT "zfproducts".* FROM "zfproducts" INNER JOIN "zfbugs" ON "zfbugs"."bug_id" = 1 INNER JOIN "zfbugs_products" ON "zfproducts"."product_id" = "zfbugs_products"."product_id" AND "zfbugs_products"."bug_id" = "zfbugs"."bug_id"', $sql);
+    }
+
     /**
      * Test adding a WHERE clause to a Zend_Db_Select object.
      */
@@ -265,6 +304,17 @@ class Zend_Db_Select_StaticTest extends Zend_Db_Select_TestCommon
         $this->assertEquals('SELECT "zfproducts".* FROM "zfproducts" WHERE ("product_id" = 2)', $sql);
     }
 
+    /**
+     * Test adding an array in the WHERE clause to a Zend_Db_Select object.
+     */
+
+    public function testSelectWhereArray()
+    {
+        $select = $this->_selectWhereArray();
+        $sql = preg_replace('/\\s+/', ' ', $select->__toString());
+        $this->assertEquals('SELECT "zfproducts".* FROM "zfproducts" WHERE ("product_id" IN (1, 2, 3))', $sql);
+    }
+
     /**
      * test adding more WHERE conditions,
      * which should be combined with AND by default.
@@ -290,7 +340,31 @@ class Zend_Db_Select_StaticTest extends Zend_Db_Select_TestCommon
     }
 
     /**
-     * Test adding an OR WHERE clause to a Zend_Db_Select object.
+     * Test support for where() with a parameter,
+     * e.g. where('id = ?', 1).
+     */
+
+    public function testSelectWhereWithType()
+    {
+        $select = $this->_selectWhereWithType();
+        $sql = preg_replace('/\\s+/', ' ', $select->__toString());
+        $this->assertEquals('SELECT "zfproducts".* FROM "zfproducts" WHERE ("product_id" = 2)', $sql);
+    }
+
+    /**
+     * Test support for where() with a float parameter,
+     * e.g. where('id = ?', 1).
+     */
+
+    public function testSelectWhereWithTypeFloat()
+    {
+        $select = $this->_selectWhereWithTypeFloat();
+        $sql = preg_replace('/\\s+/', ' ', $select->__toString());
+        $this->assertEquals('SELECT "zfprice".* FROM "zfprice" WHERE ("price_total" = 200.450000)', $sql);
+    }
+
+    /** 
+     *      * Test adding an OR WHERE clause to a Zend_Db_Select object.
      */
 
     public function testSelectWhereOr()
@@ -550,6 +624,13 @@ class Zend_Db_Select_StaticTest extends Zend_Db_Select_TestCommon
         $this->assertEquals('SELECT "zfproducts".* FROM "zfproducts" ORDER BY "product_id" ASC LIMIT 1 OFFSET 1', $sql);
     }
 
+    public function testSelectUnionString()
+    {
+        $select = $this->_selectUnionString();
+        $sql = preg_replace('/\\s+/', ' ', $select->__toString());
+        $this->assertEquals('SELECT "bug_id" AS "id", "bug_status" AS "name" FROM "zfbugs" UNION SELECT "product_id" AS "id", "product_name" AS "name" FROM "zfproducts" ORDER BY "id" ASC', $sql);
+    }
+
     public function getDriver()
     {
         return 'Static';
