@@ -16,9 +16,9 @@
  * @category   Zend
  * @package    Zend_Db
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2007 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: TestCommon.php 6896 2007-11-22 08:19:59Z thomas $
+ * @version    $Id: TestCommon.php 7508 2008-01-19 03:12:38Z peptolab $
  */
 
 
@@ -35,7 +35,7 @@ PHPUnit_Util_Filter::addFileToFilter(__FILE__);
  * @category   Zend
  * @package    Zend_Db
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2007 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 abstract class Zend_Db_Select_TestCommon extends Zend_Db_TestSetup
@@ -62,6 +62,12 @@ abstract class Zend_Db_Select_TestCommon extends Zend_Db_TestSetup
         $this->assertEquals(1, $row['product_id']); // correct data
     }
 
+    public function testSelectToString()
+    {
+        $select = $this->_select();
+        $this->assertEquals($select->__toString(), $select->assemble()); // correct data
+    }
+
     /**
      * Test basic use of the Zend_Db_Select class.
      */
@@ -245,6 +251,114 @@ abstract class Zend_Db_Select_TestCommon extends Zend_Db_TestSetup
         $this->assertEquals(3, count($result));
     }
 
+    /**
+     * Test support for nested select in from()
+     */
+    protected function _selectFromSelectObject()
+    {
+        $subquery = $this->_db->select()
+            ->from('subqueryTable');
+
+        $select = $this->_db->select()
+            ->from($subquery);
+        return $select;
+    }
+
+    public function testSelectFromSelectObject()
+    {
+        $select = $this->_selectFromSelectObject();
+        $query = $select->assemble();
+        $cmp = 'SELECT ' . $this->_db->quoteIdentifier('t') . '.* FROM (SELECT '
+                         . $this->_db->quoteIdentifier('subqueryTable') . '.* FROM '
+                         . $this->_db->quoteIdentifier('subqueryTable') . ') AS '
+                         . $this->_db->quoteIdentifier('t');
+        $this->assertEquals($query, $cmp);
+    }
+
+    /**
+     * Test support for nested select in from()
+     */
+    protected function _selectColumnsReset()
+    {
+        $select = $this->_db->select()
+            ->from(array('p' => 'zfproducts'), array('product_id', 'product_name'));
+        return $select;
+    }
+
+    public function testSelectColumnsReset()
+    {
+        $select = $this->_selectColumnsReset()
+            ->reset(Zend_Db_Select::COLUMNS)
+            ->columns('product_name');
+        $stmt = $this->_db->query($select);
+        $result = $stmt->fetchAll();
+        $this->assertContains('product_name', array_keys($result[0]));
+        $this->assertNotContains('product_id', array_keys($result[0]));
+
+        $select = $this->_selectColumnsReset()
+            ->reset(Zend_Db_Select::COLUMNS)
+            ->columns('p.product_name');
+        $stmt = $this->_db->query($select);
+        $result = $stmt->fetchAll();
+        $this->assertContains('product_name', array_keys($result[0]));
+        $this->assertNotContains('product_id', array_keys($result[0]));
+
+        $select = $this->_selectColumnsReset()
+            ->reset(Zend_Db_Select::COLUMNS)
+            ->columns('product_name', 'p');
+        $stmt = $this->_db->query($select);
+        $result = $stmt->fetchAll();
+        $this->assertContains('product_name', array_keys($result[0]));
+        $this->assertNotContains('product_id', array_keys($result[0]));
+    }
+
+    public function testSelectColumnsResetBeforeFrom()
+    {
+        $select = $this->_selectColumnsReset();
+        try {
+            $select->reset(Zend_Db_Select::COLUMNS)
+                   ->reset(Zend_Db_Select::FROM)
+                   ->columns('product_id');
+            $this->fail('Expected exception of type "Zend_Db_Select_Exception"');
+        } catch (Zend_Exception $e) {
+            $this->assertType('Zend_Db_Select_Exception', $e,
+                              'Expected exception of type "Zend_Db_Select_Exception", got ' . get_class($e));
+            $this->assertEquals("No table has been specified for the FROM clause", $e->getMessage());
+        }
+    }
+
+    protected function _selectColumnWithColonQuotedParameter()
+    {
+        $product_id = $this->_db->quoteIdentifier('product_id');
+
+        $select = $this->_db->select()
+            ->from('zfproducts')
+            ->where($product_id . ' = ?', "as'as:x");
+        return $select;
+    }
+
+    public function testSelectColumnWithColonQuotedParameter()
+    {
+        $stmt = $select = $this->_selectColumnWithColonQuotedParameter()
+            ->query();
+        $result = $stmt->fetchAll();
+        $this->assertEquals(0, count($result));
+    }
+
+    /**
+     * Test support for FOR UPDATE
+     * e.g. from('schema.table').
+     */
+    public function testSelectFromForUpdate()
+    {
+        $select = $this->_db->select()
+            ->from("zfproducts")
+            ->forUpdate();
+        $stmt = $this->_db->query($select);
+        $result = $stmt->fetchAll();
+        $this->assertEquals(3, count($result));
+    }
+
     /**
      * Test adding a JOIN to a Zend_Db_Select object.
      */
@@ -320,6 +434,33 @@ abstract class Zend_Db_Select_TestCommon extends Zend_Db_TestSetup
         $this->assertEquals(3, count($result[0]));
     }
 
+    /**
+     * Test adding a JOIN to a Zend_Db_Select object.
+     */
+    protected function _selectJoinWithNocolumns()
+    {
+        $products = $this->_db->quoteIdentifier('zfproducts');
+        $bug_id = $this->_db->quoteIdentifier('bug_id');
+        $product_id = $this->_db->quoteIdentifier('product_id');
+        $bugs_products = $this->_db->quoteIdentifier('zfbugs_products');
+        $bugs = $this->_db->quoteIdentifier('zfbugs');
+
+        $select = $this->_db->select()
+            ->from('zfproducts')
+            ->join('zfbugs', "$bugs.$bug_id = 1", array())
+            ->join('zfbugs_products', "$products.$product_id = $bugs_products.$product_id AND $bugs_products.$bug_id = $bugs.$bug_id", null);
+        return $select;
+    }
+
+    public function testSelectJoinWithNocolumns()
+    {
+        $select = $this->_selectJoinWithNocolumns();
+        $stmt = $this->_db->query($select);
+        $result = $stmt->fetchAll();
+        $this->assertEquals(3, count($result));
+        $this->assertEquals(2, count($result[0]));
+    }
+
     /**
      * Test adding an outer join to a Zend_Db_Select object.
      */
@@ -373,7 +514,7 @@ abstract class Zend_Db_Select_TestCommon extends Zend_Db_TestSetup
     public function testJoinLeftTableAliasesColumnOrderPreserve()
     {
         $select = $this->_selectJoinLeftTableAliasesColumnOrderPreserve();
-        $this->assertRegExp('/^.*b.*bug_id.*,.*bp.*product_id.*,.*b.*bug_description.*$/s', $select->__toString());
+        $this->assertRegExp('/^.*b.*bug_id.*,.*bp.*product_id.*,.*b.*bug_description.*$/s', $select->assemble());
     }
 
     /**
@@ -448,6 +589,104 @@ abstract class Zend_Db_Select_TestCommon extends Zend_Db_TestSetup
         $this->assertEquals(3, count($result[0]));
     }
 
+    protected function _selectJoinUsing()
+    {
+        $products = $this->_db->quoteIdentifier('zfproducts');
+        $bugs_products = $this->_db->quoteIdentifier('zfbugs_products');
+        $product_id = $this->_db->quoteIdentifier('product_id');
+
+        $select = $this->_db->select()
+            ->from('zfproducts')
+            ->joinUsing("zfbugs_products", "$product_id")
+            ->where("$bugs_products.$product_id < ?", 3);
+        return $select;
+    }
+
+    public function testSelectMagicMethod()
+    {
+        $select = $this->_selectJoinUsing();
+        try {
+            $select->foo();
+            $this->fail('Expected exception of type "Zend_Db_Select_Exception"');
+        } catch (Zend_Exception $e) {
+            $this->assertType('Zend_Db_Select_Exception', $e,
+                              'Expected exception of type "Zend_Db_Select_Exception", got ' . get_class($e));
+            $this->assertEquals("Unrecognized method 'foo()'", $e->getMessage());
+        }
+    }
+
+    public function testSelectJoinUsing()
+    {
+        $select = $this->_selectJoinUsing();
+        $sql = preg_replace('/\\s+/', ' ', $select->assemble());
+        $stmt = $this->_db->query($select);
+        $result = $stmt->fetchAll();
+        $this->assertEquals(3, count($result));
+        $this->assertEquals(1, $result[0]['product_id']);
+    }
+
+    protected function _selectJoinInnerUsing()
+    {
+        $products = $this->_db->quoteIdentifier('zfproducts');
+        $bugs_products = $this->_db->quoteIdentifier('zfbugs_products');
+        $product_id = $this->_db->quoteIdentifier('product_id');
+
+        $select = $this->_db->select()
+            ->from('zfproducts')
+            ->joinInnerUsing("zfbugs_products", "$product_id")
+            ->where("$bugs_products.$product_id < ?", 3);
+        return $select;
+    }
+
+    public function testSelectJoinInnerUsing()
+    {
+        $select = $this->_selectJoinInnerUsing();
+        $sql = preg_replace('/\\s+/', ' ', $select->assemble());
+        $stmt = $this->_db->query($select);
+        $result = $stmt->fetchAll();
+        $this->assertEquals(3, count($result));
+        $this->assertEquals(1, $result[0]['product_id']);
+    }
+
+    public function testSelectJoinInnerUsingException()
+    {
+        $select = $this->_selectJoinInnerUsing();
+        try {
+            $select->joinFooUsing();
+            $this->fail('Expected exception of type "Zend_Db_Select_Exception"');
+        } catch (Zend_Exception $e) {
+            $this->assertType('Zend_Db_Select_Exception', $e,
+                              'Expected exception of type "Zend_Db_Select_Exception", got ' . get_class($e));
+            $this->assertEquals("Unrecognized method 'joinFooUsing()'", $e->getMessage());
+        }
+    }
+
+    protected function _selectJoinCrossUsing()
+    {
+        $products = $this->_db->quoteIdentifier('zfproducts');
+        $bugs_products = $this->_db->quoteIdentifier('zfbugs_products');
+        $product_id = $this->_db->quoteIdentifier('product_id');
+
+        $select = $this->_db->select()
+            ->from('zfproducts')
+            ->where("$bugs_products.$product_id < ?", 3);
+        return $select;
+    }
+
+    public function testSelectJoinCrossUsing()
+    {
+        $product_id = $this->_db->quoteIdentifier('product_id');
+        $select = $this->_selectJoinCrossUsing();
+        try {
+            $select->joinCrossUsing("zfbugs_products", "$product_id");
+            $this->fail('Expected exception of type "Zend_Db_Select_Exception"');
+        } catch (Zend_Exception $e) {
+            $this->assertType('Zend_Db_Select_Exception', $e,
+                              'Expected exception of type "Zend_Db_Select_Exception", got ' . get_class($e));
+            $this->assertEquals("Cannot perform a joinUsing with method 'joinCrossUsing()'", $e->getMessage());
+        }
+    }
+
     /**
      * Test adding a WHERE clause to a Zend_Db_Select object.
      */
@@ -470,6 +709,49 @@ abstract class Zend_Db_Select_TestCommon extends Zend_Db_TestSetup
         $this->assertEquals(2, $result[0]['product_id']);
     }
 
+    /**
+     * Test support for nested select in from()
+     */
+    protected function _selectWhereSelectObject()
+    {
+        $subquery = $this->_db->select()
+            ->from('subqueryTable');
+
+        $select = $this->_db->select()
+            ->from('table')
+            ->where('foo IN ?', $subquery);
+        return $select;
+    }
+
+    public function testSelectWhereSelectObject()
+    {
+        $select = $this->_selectWhereSelectObject();
+        $query = $select->assemble();
+        $cmp = 'SELECT ' . $this->_db->quoteIdentifier('table') . '.* FROM '
+                         . $this->_db->quoteIdentifier('table') . ' WHERE (foo IN (SELECT '
+                         . $this->_db->quoteIdentifier('subqueryTable') . '.* FROM '
+                         . $this->_db->quoteIdentifier('subqueryTable') . '))';
+        $this->assertEquals($query, $cmp);
+    }
+    
+    protected function _selectWhereArray()
+    {
+        $product_id = $this->_db->quoteIdentifier('product_id');
+
+        $select = $this->_db->select()
+            ->from('zfproducts')
+            ->where("$product_id IN (?)", array(1, 2, 3));
+        return $select;
+    }
+    
+    public function testSelectWhereArray()
+    {
+        $select = $this->_selectWhereArray();
+        $stmt = $this->_db->query($select);
+        $result = $stmt->fetchAll();
+        $this->assertEquals(3, count($result));
+    }
+
     /**
      * test adding more WHERE conditions,
      * which should be combined with AND by default.
@@ -517,6 +799,68 @@ abstract class Zend_Db_Select_TestCommon extends Zend_Db_TestSetup
     }
 
     /**
+     * Test support for where() with a specified type,
+     * e.g. where('id = ?', 1, 'int').
+     */
+    protected function _selectWhereWithType()
+    {
+        $product_id = $this->_db->quoteIdentifier('product_id');
+
+        $select = $this->_db->select()
+            ->from('zfproducts')
+            ->where("$product_id = ?", 2, 'int');
+        return $select;
+    }
+
+    public function testSelectWhereWithType()
+    {
+        $select = $this->_selectWhereWithType();
+        $stmt = $this->_db->query($select);
+        $result = $stmt->fetchAll();
+        $this->assertEquals(1, count($result));
+        $this->assertEquals(2, $result[0]['product_id']);
+    }
+
+    /**
+     * Test support for where() with a specified type,
+     * e.g. where('id = ?', 1, 'int').
+     */
+    protected function _selectWhereWithTypeFloat()
+    {
+        $price_total = $this->_db->quoteIdentifier('price_total');
+
+        $select = $this->_db->select()
+            ->from('zfprice')
+            ->where("$price_total = ?", 200.45, Zend_Db::FLOAT_TYPE);
+        return $select;
+    }
+
+    public function testSelectWhereWithTypeFloat()
+    {
+        $locale = setlocale(LC_ALL, null);
+
+        $select = $this->_selectWhereWithTypeFloat();
+        $stmt = $this->_db->query($select);
+        $result = $stmt->fetchAll();
+        $this->assertEquals(1, count($result));
+        $this->assertEquals(200.45, $result[0]['price_total']);
+
+        try {
+            setlocale(LC_ALL, 'fr_BE.UTF-8');
+            $select = $this->_selectWhereWithTypeFloat();
+            $stmt = $this->_db->query($select);
+            $result = $stmt->fetchAll();
+            $this->assertEquals(1, count($result));
+            $this->assertEquals(200.45, $result[0]['price_total']);
+        } catch (Zend_Exception $e) {
+            setlocale(LC_ALL, $locale);
+            throw $e;
+        }
+
+        setlocale(LC_ALL, $locale);
+    }
+
+    /** 
      * Test adding an OR WHERE clause to a Zend_Db_Select object.
      */
     protected function _selectWhereOr()
@@ -1083,4 +1427,35 @@ abstract class Zend_Db_Select_TestCommon extends Zend_Db_TestSetup
         $this->assertTrue(empty($from));
     }
 
+    /**
+     * Test the UNION statement for a Zend_Db_Select object.
+     */
+    protected function _selectUnionString()
+    {
+        $bugs = $this->_db->quoteIdentifier('zfbugs');
+        $bug_id = $this->_db->quoteIdentifier('bug_id');
+        $bug_status = $this->_db->quoteIdentifier('bug_status');
+        $products = $this->_db->quoteIdentifier('zfproducts');
+        $product_id = $this->_db->quoteIdentifier('product_id');
+        $product_name = $this->_db->quoteIdentifier('product_name');
+        $id = $this->_db->quoteIdentifier('id');
+        $name = $this->_db->quoteIdentifier('name');
+        $sql1 = "SELECT $bug_id AS $id, $bug_status AS $name FROM $bugs";
+        $sql2 = "SELECT $product_id AS $id, $product_name AS $name FROM $products";
+
+        $select = $this->_db->select()
+            ->union(array($sql1, $sql2))
+            ->order('id');
+        return $select;
+    }
+
+    public function testSelectUnionString()
+    {
+        $select = $this->_selectUnionString();
+        $stmt = $this->_db->query($select);
+        $result = $stmt->fetchAll();
+        $this->assertEquals(7, count($result));
+        $this->assertEquals(1, $result[0]['id']);
+    }
+
 }
