@@ -16,16 +16,16 @@
  * @category   Zend
  * @package    Zend_Filter
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2007 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: AllTests.php 4412 2007-04-06 21:17:32Z zendbot $
+ * @version    $Id: InputTest.php 11754 2008-10-08 19:38:31Z andries $
  */
 
 
 /**
  * Test helper
  */
-require_once dirname(dirname(dirname(__FILE__))) . DIRECTORY_SEPARATOR . 'TestHelper.php';
+require_once dirname(__FILE__) . '/../../TestHelper.php';
 
 /**
  * @see Zend_Filter_Input
@@ -42,7 +42,7 @@ require_once 'Zend/Loader.php';
  * @category   Zend
  * @package    Zend_Filter
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2007 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 class Zend_Filter_InputTest extends PHPUnit_Framework_TestCase
@@ -58,9 +58,6 @@ class Zend_Filter_InputTest extends PHPUnit_Framework_TestCase
         );
         $input = new Zend_Filter_Input($filters, null, $data);
 
-        $this->assertFalse($input->hasMissing(), 'Expected hasMissing() to return false');
-        $this->assertFalse($input->hasInvalid(), 'Expected hasInvalid() to return false');
-        $this->assertFalse($input->hasUnknown(), 'Expected hasUnknown() to return false');
         $this->assertTrue($input->hasValid(), 'Expected hasValid() to return true');
 
         $month = $input->month;
@@ -205,7 +202,7 @@ class Zend_Filter_InputTest extends PHPUnit_Framework_TestCase
         $this->assertType('array', $messages);
         $this->assertEquals(array('month'), array_keys($messages));
         $this->assertType('array', $messages['month']);
-        $this->assertEquals("'6abc ' contains not only digit characters", $messages['month'][0]);
+        $this->assertEquals("'6abc ' contains not only digit characters", current($messages['month']));
 
         $errors = $input->getErrors();
         $this->assertType('array', $errors);
@@ -265,7 +262,7 @@ class Zend_Filter_InputTest extends PHPUnit_Framework_TestCase
         $messages = $input->getMessages();
         $this->assertType('array', $messages);
         $this->assertEquals(array('month2'), array_keys($messages));
-        $this->assertEquals("'13' is not between '1' and '12', inclusively", $messages['month2'][0]);
+        $this->assertEquals("'13' is not between '1' and '12', inclusively", current($messages['month2']));
     }
 
     public function testValidatorChain()
@@ -295,9 +292,9 @@ class Zend_Filter_InputTest extends PHPUnit_Framework_TestCase
         $this->assertType('array', $messages['field2']);
         $this->assertType('array', $messages['field3']);
         $this->assertEquals("'abc123' contains not only digit characters",
-            $messages['field2'][0]);
+            current($messages['field2']));
         $this->assertEquals("'150' is not between '1' and '100', inclusively",
-            $messages['field3'][0]);
+            current($messages['field3']));
     }
 
     public function testValidatorInvalidFieldInMultipleRules()
@@ -329,9 +326,9 @@ class Zend_Filter_InputTest extends PHPUnit_Framework_TestCase
         $this->assertType('array', $messages['field2a']);
         $this->assertType('array', $messages['field2b']);
         $this->assertEquals("'abc123' contains not only digit characters",
-            $messages['field2a'][0]);
+            current($messages['field2a']));
         $this->assertEquals("'abc123' is not between '1' and '100', inclusively",
-            $messages['field2b'][0]);
+            current($messages['field2b']));
     }
 
     public function testValidatorWildcardRule()
@@ -376,7 +373,7 @@ class Zend_Filter_InputTest extends PHPUnit_Framework_TestCase
         $this->assertType('array', $messages);
         $this->assertEquals(array('field2'), array_keys($messages));
         $this->assertEquals("'123' has not only alphabetic characters",
-            $messages['field2'][0]);
+            current($messages['field2']));
     }
 
     public function testValidatorMultiField()
@@ -397,7 +394,7 @@ class Zend_Filter_InputTest extends PHPUnit_Framework_TestCase
             )
         );
         $options = array(
-            Zend_Filter_Input::NAMESPACE => 'TestNamespace'
+            Zend_Filter_Input::INPUT_NAMESPACE => 'TestNamespace'
         );
 
         $ip = get_include_path();
@@ -417,7 +414,7 @@ class Zend_Filter_InputTest extends PHPUnit_Framework_TestCase
         $this->assertType('array', $messages);
         $this->assertEquals(array('rule2'), array_keys($messages));
         $this->assertEquals("Not all strings in the argument are equal",
-            $messages['rule2'][0]);
+            current($messages['rule2']));
     }
 
     public function testValidatorBreakChain()
@@ -426,9 +423,15 @@ class Zend_Filter_InputTest extends PHPUnit_Framework_TestCase
             'field1' => '150',
             'field2' => '150'
         );
+
         Zend_Loader::loadClass('Zend_Validate_Between');
+
         $btw1 = new Zend_Validate_Between(1, 100);
+
         $btw2 = new Zend_Validate_Between(1, 125);
+        $messageUserDefined = 'Something other than the default message';
+        $btw2->setMessage($messageUserDefined, Zend_Validate_Between::NOT_BETWEEN);
+
         $validators = array(
             'field1' => array($btw1, $btw2),
             'field2' => array($btw1, $btw2, Zend_Filter_Input::BREAK_CHAIN => true)
@@ -443,14 +446,16 @@ class Zend_Filter_InputTest extends PHPUnit_Framework_TestCase
         $messages = $input->getMessages();
         $this->assertType('array', $messages);
         $this->assertEquals(array('field1', 'field2'), array_keys($messages));
-        $this->assertEquals(2, count($messages['field1']), 'Expected rule for field1 to break 2 validators');
-        $this->assertEquals(1, count($messages['field2']), 'Expected rule for field2 to break 1 validator');
-        $this->assertEquals("'150' is not between '1' and '100', inclusively",
-            $messages['field1'][0]);
-        $this->assertEquals("'150' is not between '1' and '125', inclusively",
-            $messages['field1'][1]);
-        $this->assertEquals("'150' is not between '1' and '100', inclusively",
-            $messages['field2'][0]);
+        $this->assertEquals(
+            $messageUserDefined,
+            current($messages['field1']),
+            'Expected message to break 2 validators, the message of the latter overwriting that of the former'
+            );
+        $this->assertEquals(
+            "'150' is not between '1' and '100', inclusively",
+            current($messages['field2']),
+            'Expected rule for field2 to break the validation chain at the first validator'
+            );
     }
 
     public function testValidatorAllowEmpty()
@@ -481,7 +486,7 @@ class Zend_Filter_InputTest extends PHPUnit_Framework_TestCase
         $messages = $input->getMessages();
         $this->assertType('array', $messages);
         $this->assertEquals(array('field1'), array_keys($messages));
-        $this->assertEquals("'' is an empty string", $messages['field1'][0]);
+        $this->assertEquals("'' is an empty string", current($messages['field1']));
     }
 
     public function testValidatorAllowEmptyNoValidatorChain()
@@ -518,7 +523,7 @@ class Zend_Filter_InputTest extends PHPUnit_Framework_TestCase
         $input = new Zend_Filter_Input($filters, $validators, $data);
 
         if ($input->hasInvalid()) {
-            $message = $input->getMessages();
+            $input->getMessages();
         }
 
         $this->assertFalse($input->hasMissing(), 'Expected hasMissing() to return false');
@@ -560,12 +565,12 @@ class Zend_Filter_InputTest extends PHPUnit_Framework_TestCase
         $this->assertType('array', $messages);
         $this->assertEquals(array('field1Rule'), array_keys($messages));
         $this->assertType('array', $messages['field1Rule']);
-        $this->assertEquals("You cannot give an empty value for field 'field1', according to rule 'field1Rule'", $messages['field1Rule'][0]);
+        $this->assertEquals("You cannot give an empty value for field 'field1', according to rule 'field1Rule'", current($messages['field1Rule']));
     }
 
     public function testValidatorDefault()
     {
-        $validators = array(  
+        $validators = array(
             'field1'   => array('presence' => 'required', 'allowEmpty' => false),
             'field2'   => array('presence' => 'optional', 'allowEmpty' => false),
             'field3'   => array('presence' => 'required', 'allowEmpty' => true),
@@ -573,10 +578,10 @@ class Zend_Filter_InputTest extends PHPUnit_Framework_TestCase
             'field5'   => array('presence' => 'required', 'allowEmpty' => false, 'default' => 'field5default'),
             'field6'   => array('presence' => 'optional', 'allowEmpty' => false, 'default' => 'field6default'),
             'field7'   => array('presence' => 'required', 'allowEmpty' => true, 'default' => 'field7default'),
-            'field8'   => array('presence' => 'optional', 'allowEmpty' => true, 'default' => 'field8default'),
+            'field8'   => array('presence' => 'optional', 'allowEmpty' => true, 'default' => array('field8default', 'field8default2')),
         );
         $data = array();
-        $input = new Zend_Filter_Input(null, $validators, $data); 
+        $input = new Zend_Filter_Input(null, $validators, $data);
 
         $this->assertTrue($input->hasMissing(), 'Expected hasMissing() to return true');
         $this->assertFalse($input->hasInvalid(), 'Expected hasInvalid() to return false');
@@ -600,7 +605,7 @@ class Zend_Filter_InputTest extends PHPUnit_Framework_TestCase
 
     public function testValidatorDefaultDoesNotOverwriteData()
     {
-        $validators = array(  
+        $validators = array(
             'field1'   => array('presence' => 'required', 'allowEmpty' => false, 'default' => 'abcd'),
             'field2'   => array('presence' => 'optional', 'allowEmpty' => false, 'default' => 'abcd'),
             'field3'   => array('presence' => 'required', 'allowEmpty' => true, 'default' => 'abcd'),
@@ -612,7 +617,7 @@ class Zend_Filter_InputTest extends PHPUnit_Framework_TestCase
             'field3' => 'ABCD',
             'field4' => 'ABCD'
         );
-        $input = new Zend_Filter_Input(null, $validators, $data); 
+        $input = new Zend_Filter_Input(null, $validators, $data);
 
         $this->assertFalse($input->hasMissing(), 'Expected hasMissing() to return false');
         $this->assertFalse($input->hasInvalid(), 'Expected hasInvalid() to return false');
@@ -627,12 +632,12 @@ class Zend_Filter_InputTest extends PHPUnit_Framework_TestCase
 
     public function testValidatorNotAllowEmpty()
     {
-        $filters = array(  
+        $filters = array(
             'field1'   => 'Digits',
             'field2'   => 'Alnum'
         );
-         
-        $validators = array(  
+
+        $validators = array(
             'field1'   => array('Digits'),
             'field2'   => array('Alnum'),
             'field3'   => array('Alnum', 'presence' => 'required')
@@ -641,7 +646,7 @@ class Zend_Filter_InputTest extends PHPUnit_Framework_TestCase
             'field1' => 'asd1', // Valid data
             'field2' => '$'     // Invalid data
         );
-        $input = new Zend_Filter_Input($filters, $validators, $data); 
+        $input = new Zend_Filter_Input($filters, $validators, $data);
 
         $this->assertTrue($input->hasMissing(), 'Expected hasMissing() to return true');
         $this->assertTrue($input->hasInvalid(), 'Expected hasInvalid() to return true');
@@ -652,7 +657,7 @@ class Zend_Filter_InputTest extends PHPUnit_Framework_TestCase
         $this->assertType('array', $messages);
         $this->assertEquals(array('field2', 'field3'), array_keys($messages));
         $this->assertType('array', $messages['field2']);
-        $this->assertEquals("'' is an empty string", $messages['field2'][0]);
+        $this->assertEquals("'' is an empty string", current($messages['field2']));
     }
 
     public function testValidatorMessagesSingle()
@@ -676,7 +681,7 @@ class Zend_Filter_InputTest extends PHPUnit_Framework_TestCase
         $this->assertType('array', $messages);
         $this->assertEquals(array('month'), array_keys($messages));
         $this->assertEquals(1, count($messages['month']));
-        $this->assertEquals($digitsMesg, $messages['month'][0]);
+        $this->assertEquals($digitsMesg, current($messages['month']));
     }
 
     public function testValidatorMessagesMultiple()
@@ -735,8 +740,10 @@ class Zend_Filter_InputTest extends PHPUnit_Framework_TestCase
         $this->assertType('array', $messages);
         $this->assertEquals(array('month'), array_keys($messages));
         $this->assertEquals(2, count($messages['month']));
-        $this->assertEquals("'13abc' contains not only digit characters", $messages['month'][0]);
-        // $this->assertEquals($betweenMesg, $messages['month'][1]);
+        $this->assertEquals("'13abc' contains not only digit characters", current($messages['month']));
+        /**
+         * @todo $this->assertEquals($betweenMesg, next($messages['month']));
+         */
     }
 
     public function testValidatorMessagesSingleWithKeys()
@@ -1018,7 +1025,7 @@ class Zend_Filter_InputTest extends PHPUnit_Framework_TestCase
             'field3' => 'digits'
         );
         $options = array(
-            Zend_Filter_Input::NAMESPACE => 'TestNamespace'
+            Zend_Filter_Input::INPUT_NAMESPACE => 'TestNamespace'
         );
 
         $ip = get_include_path();
@@ -1041,7 +1048,53 @@ class Zend_Filter_InputTest extends PHPUnit_Framework_TestCase
         $messages = $input->getMessages();
         $this->assertType('array', $messages);
         $this->assertThat($messages, $this->arrayHasKey('field1'));
-        $this->assertEquals("'abc' contains not only digit characters", $messages['field1'][0]);
+        $this->assertEquals("'abc' contains not only digit characters", current($messages['field1']));
+    }
+
+    public function testGetPluginLoader()
+    {
+    	$input = new Zend_Filter_Input(null, null);
+
+    	$loader = $input->getPluginLoader(Zend_Filter_Input::VALIDATE);
+        $this->assertType('Zend_Loader_PluginLoader', $loader,
+            'Expected object of type Zend_Loader_PluginLoader, got ' , get_class($loader));
+
+        try {
+    		$loader = $input->getPluginLoader('foo');
+            $this->fail('Expected to catch Zend_Filter_Exception');
+        } catch (Zend_Exception $e) {
+            $this->assertType('Zend_Filter_Exception', $e,
+                'Expected object of type Zend_Filter_Exception, got '.get_class($e));
+            $this->assertEquals('Invalid type "foo" provided to getPluginLoader()',
+                $e->getMessage());
+        }
+
+    }
+
+    public function testSetPluginLoader()
+    {
+    	$input = new Zend_Filter_Input(null, null);
+
+    	$loader = new Zend_Loader_PluginLoader();
+
+    	$input->setPluginLoader($loader, Zend_Filter_Input::VALIDATE);
+    }
+
+    public function testSetPluginLoaderInvalidType()
+    {
+    	$input = new Zend_Filter_Input(null, null);
+
+    	$loader = new Zend_Loader_PluginLoader();
+
+        try {
+        	$input->setPluginLoader($loader, 'foo');
+            $this->fail('Expected to catch Zend_Filter_Exception');
+        } catch (Zend_Exception $e) {
+            $this->assertType('Zend_Filter_Exception', $e,
+                'Expected object of type Zend_Filter_Exception, got '.get_class($e));
+            $this->assertEquals('Invalid type "foo" provided to setPluginLoader()',
+                $e->getMessage());
+        }
     }
 
     public function testNamespaceExceptionClassNotFound()
@@ -1058,9 +1111,9 @@ class Zend_Filter_InputTest extends PHPUnit_Framework_TestCase
             $this->assertTrue($input->hasInvalid(), 'Expected hasInvalid() to return true');
             $this->fail('Expected to catch Zend_Filter_Exception');
         } catch (Zend_Exception $e) {
-            $this->assertType('Zend_Filter_Exception', $e,
+            $this->assertType('Zend_Loader_PluginLoader_Exception', $e,
                 'Expected object of type Zend_Filter_Exception, got '.get_class($e));
-            $this->assertEquals("Unable to find the implementation of the 'MyDigits' class",
+            $this->assertContains("Plugin by name MyDigits was not found in the registry",
                 $e->getMessage());
         }
     }
@@ -1168,7 +1221,7 @@ class Zend_Filter_InputTest extends PHPUnit_Framework_TestCase
         $this->assertEquals(array('field1'), array_keys($messages));
         $this->assertEquals(1, count($messages['field1']), 'Expected rule for field1 to break 1 validator');
         $this->assertEquals("'150' is not between '1' and '100', inclusively",
-            $messages['field1'][0]);
+            current($messages['field1']));
     }
 
     public function testOptionEscapeFilter()
@@ -1202,7 +1255,7 @@ class Zend_Filter_InputTest extends PHPUnit_Framework_TestCase
             'field3' => 'digits'
         );
         $options = array(
-            Zend_Filter_Input::NAMESPACE => 'TestNamespace'
+            Zend_Filter_Input::INPUT_NAMESPACE => 'TestNamespace'
         );
 
         $ip = get_include_path();
@@ -1224,7 +1277,7 @@ class Zend_Filter_InputTest extends PHPUnit_Framework_TestCase
         $messages = $input->getMessages();
         $this->assertType('array', $messages);
         $this->assertThat($messages, $this->arrayHasKey('field1'));
-        $this->assertEquals("'abc' contains not only digit characters", $messages['field1'][0]);
+        $this->assertEquals("'abc' contains not only digit characters", current($messages['field1']));
     }
 
     public function testOptionPresence()
