@@ -32,6 +32,11 @@ if (!defined('PHPUnit_MAIN_METHOD')) {
 require_once 'PHPUnit/Framework/TestSuite.php';
 require_once 'PHPUnit/TextUI/TestRunner.php';
 
+/**
+ * Tests of the authentication URL generator
+ */
+require_once 'Zend/Gdata/AuthSubTest.php';
+
 /**
  * Tests that do not require online access to servers
  */
@@ -41,6 +46,7 @@ require_once 'Zend/Gdata/App/AuthorTest.php';
 require_once 'Zend/Gdata/App/CategoryTest.php';
 require_once 'Zend/Gdata/App/ContentTest.php';
 require_once 'Zend/Gdata/App/ControlTest.php';
+require_once 'Zend/Gdata/App/EntryTest.php';
 require_once 'Zend/Gdata/App/FeedTest.php';
 require_once 'Zend/Gdata/App/GeneratorTest.php';
 require_once 'Zend/Gdata/App/CaptchaRequiredExceptionTest.php';
@@ -185,6 +191,11 @@ class Zend_Gdata_AllTests
     {
         $suite = new PHPUnit_Framework_TestSuite('Zend Framework - Zend_Gdata');
 
+        /**
+         * Tests of the authentication URL generator
+         */
+        $suite->addTestSuite('Zend_Gdata_AuthSubTest');
+
         /**
          * Tests that do not require online access to servers
          */
@@ -194,6 +205,7 @@ class Zend_Gdata_AllTests
         $suite->addTestSuite('Zend_Gdata_App_CategoryTest');
         $suite->addTestSuite('Zend_Gdata_App_ContentTest');
         $suite->addTestSuite('Zend_Gdata_App_ControlTest');
+        $suite->addTestSuite('Zend_Gdata_App_EntryTest');
         $suite->addTestSuite('Zend_Gdata_App_FeedTest');
         $suite->addTestSuite('Zend_Gdata_App_GeneratorTest');
         $suite->addTestSuite('Zend_Gdata_App_CaptchaRequiredExceptionTest');
