@@ -4,16 +4,21 @@
  * @category   Zend
  * @package    Zend_Http
  * @subpackage UnitTests
- * @version    $Id: CookieJarTest.php 5460 2007-06-27 15:54:43Z shahar $
+ * @version    $Id: CookieJarTest.php 7366 2008-01-09 13:48:52Z shahar $
  * @copyright  Copyright (c) 2006 Zend Technologies USA Inc. (http://www.zend.com/)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 
+/**
+ * Test helper
+ */
+require_once dirname(dirname(dirname(__FILE__))) . DIRECTORY_SEPARATOR . 'TestHelper.php';
+
 require_once 'PHPUnit/Framework/TestCase.php';
 require_once 'Zend/Http/CookieJar.php';
 
 /**
- * Zend_Http_Cookie unit tests
+ * Zend_Http_CookieJar unit tests
  * 
  * @category   Zend
  * @package    Zend_Http
@@ -360,6 +365,28 @@ class Zend_Http_CookieJarTest extends PHPUnit_Framework_TestCase
     	$this->assertType('string', $cookies, '$cookies is expected to be a string');
     }
     
+	/**
+     * Test we get a proper exception when an invalid URI is passed
+     */
+    public function testExceptGetMatchingCookiesInvalidUri() 
+    {
+        $jar = new Zend_Http_CookieJar();
+    	        
+    	try {
+    	    $cookies = $jar->getMatchingCookies('invalid.com', true, Zend_Http_CookieJar::COOKIE_STRING_ARRAY);
+    		$this->fail('Expected getMatchingCookies to throw exception, invalid URI string passed');
+    	} catch (Zend_Exception $e) {
+    		// We are ok!
+    	}
+    	
+    	try {
+    		$cookies = $jar->getMatchingCookies(new stdClass(), true, Zend_Http_CookieJar::COOKIE_STRING_ARRAY);
+    		$this->fail('Expected getCookie to throw exception, invalid URI object passed');
+    	} catch (Zend_Exception $e) {
+    		// We are ok!
+    	}
+    }
+    
     /**
      * Test we can build a new object from a response object (single cookie header)
      */
