@@ -17,6 +17,10 @@ require_once 'Zend/Mail/Storage/Imap.php';
  */
 require_once 'Zend/Mail/Protocol/Imap.php';
 
+/**
+ * Zend_Config
+ */
+require_once 'Zend/Config.php';
 
 /**
  * PHPUnit test case
@@ -38,7 +42,6 @@ class Zend_Mail_ImapTest extends PHPUnit_Framework_TestCase
         $this->_params = array('host'     => TESTS_ZEND_MAIL_IMAP_HOST,
                                'user'     => TESTS_ZEND_MAIL_IMAP_USER,
                                'password' => TESTS_ZEND_MAIL_IMAP_PASSWORD);
-
         if (defined('TESTS_ZEND_MAIL_SERVER_TESTDIR') && TESTS_ZEND_MAIL_SERVER_TESTDIR) {
             if (!file_exists(TESTS_ZEND_MAIL_SERVER_TESTDIR . DIRECTORY_SEPARATOR . 'inbox')
              && !file_exists(TESTS_ZEND_MAIL_SERVER_TESTDIR . DIRECTORY_SEPARATOR . 'INBOX')) {
@@ -100,6 +103,15 @@ class Zend_Mail_ImapTest extends PHPUnit_Framework_TestCase
         }
     }
 
+    public function testConnectConfig()
+    {
+        try {
+            $mail = new Zend_Mail_Storage_Imap(new Zend_Config($this->_params));
+        } catch (Exception $e) {
+            $this->fail('exception raised while loading connection to imap server');
+        }
+    }
+
     public function testConnectFailure()
     {
         $this->_params['host'] = 'example.example';
@@ -803,4 +815,38 @@ class Zend_Mail_ImapTest extends PHPUnit_Framework_TestCase
         $result = $protocol->store(array('\Flagged'), 1, null, '+', false);
         $this->assertTrue(in_array('\Flagged', $result[1]));
     }
+    
+    public function testMove()
+    {
+        $mail = new Zend_Mail_Storage_Imap($this->_params);
+        $mail->selectFolder('subfolder/test');
+        $toCount = $mail->countMessages();
+        $mail->selectFolder('INBOX');
+        $fromCount = $mail->countMessages();
+        $mail->moveMessage(1, 'subfolder/test');
+
+
+        $this->assertEquals($fromCount - 1, $mail->countMessages());
+        $mail->selectFolder('subfolder/test');
+        $this->assertEquals($toCount + 1, $mail->countMessages());
+    }
+
+    public function testCountFlags()
+    {
+        $mail = new Zend_Mail_Storage_Imap($this->_params);
+        foreach ($mail as $id => $message) {
+        	$mail->setFlags($id, array());
+        }
+		$this->assertEquals($mail->countMessages(Zend_Mail_Storage::FLAG_SEEN), 0);
+		$this->assertEquals($mail->countMessages(Zend_Mail_Storage::FLAG_ANSWERED), 0);
+		$this->assertEquals($mail->countMessages(Zend_Mail_Storage::FLAG_FLAGGED), 0);
+
+		$mail->setFlags(1, array(Zend_Mail_Storage::FLAG_SEEN, Zend_Mail_Storage::FLAG_ANSWERED));
+		$mail->setFlags(2, array(Zend_Mail_Storage::FLAG_SEEN));
+		$this->assertEquals($mail->countMessages(Zend_Mail_Storage::FLAG_SEEN), 2);
+		$this->assertEquals($mail->countMessages(Zend_Mail_Storage::FLAG_ANSWERED), 1);
+		$this->assertEquals($mail->countMessages(array(Zend_Mail_Storage::FLAG_SEEN, Zend_Mail_Storage::FLAG_ANSWERED)), 1);
+		$this->assertEquals($mail->countMessages(array(Zend_Mail_Storage::FLAG_SEEN, Zend_Mail_Storage::FLAG_FLAGGED)), 0);
+		$this->assertEquals($mail->countMessages(Zend_Mail_Storage::FLAG_FLAGGED), 0);
+    }    	
 }
