@@ -15,14 +15,18 @@
  * @category   Zend
  * @package    Zend_View
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2007 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 
+if (!defined('PHPUnit_MAIN_METHOD')) {
+    define('PHPUnit_MAIN_METHOD', 'Zend_ViewTest::main');
+}
+
 /**
  * Test helper
  */
-require_once dirname(dirname(__FILE__)) . DIRECTORY_SEPARATOR . 'TestHelper.php';
+require_once dirname(__FILE__) . '/../TestHelper.php';
 
 /**
  * Zend_View
@@ -34,17 +38,29 @@ require_once 'Zend/View.php';
  */
 require_once 'Zend/View/Interface.php';
 
+/**
+ * Zend_Loader
+ */
+require_once 'Zend/Loader.php';
+
 /**
  * @category   Zend
  * @package    Zend_View
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2007 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 class Zend_ViewTest extends PHPUnit_Framework_TestCase
 {
+    public static function main()
+    {
+        $suite  = new PHPUnit_Framework_TestSuite("Zend_ViewTest");
+        $result = PHPUnit_TextUI_TestRunner::run($suite);
+    }
+
     public function setUp()
     {
+        $this->notices = array();
         $this->errorReporting = error_reporting();
         $this->displayErrors  = ini_get('display_errors');
     }
@@ -83,7 +99,7 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
      */
     public function testDefaultFilterPath()
     {
-        $this->_testDefaultPath('filter');
+        $this->_testDefaultPath('filter', false);
     }
 
     /**
@@ -133,14 +149,13 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
             $this->assertEquals(0, count($paths));
         } else {
             $this->assertEquals(1, count($paths));
-            $item = $paths[0];
 
             $prefix = 'Zend_View_' . ucfirst($pathType) . '_';
-            $this->assertEquals($prefix, $item['prefix']);
+            $this->assertTrue(array_key_exists($prefix, $paths));
 
             if ($testReadability) {
-                $this->assertTrue(is_dir($item['dir']));
-                $this->assertTrue(is_readable($item['dir']));
+                $path = current($paths[$prefix]);
+                $this->assertTrue(Zend_Loader::isReadable($path));
             }
         }
     }
@@ -160,16 +175,14 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
         $reflector     = $view->getAllPaths();
         $expectedPaths = $reflector[$pathType];
 
-        if ('script' == $pathType) {
-            array_unshift($expectedPaths, 'baz' . DIRECTORY_SEPARATOR);
-            array_unshift($expectedPaths, 'bar' . DIRECTORY_SEPARATOR);
-            array_unshift($expectedPaths, 'foo' . DIRECTORY_SEPARATOR);
-        } else {
-            array_unshift($expectedPaths, array('prefix' => $prefix, 'dir' => 'baz' . DIRECTORY_SEPARATOR));
-            array_unshift($expectedPaths, array('prefix' => $prefix, 'dir' => 'bar' . DIRECTORY_SEPARATOR));
-            array_unshift($expectedPaths, array('prefix' => $prefix, 'dir' => 'foo' . DIRECTORY_SEPARATOR));
+        if ($pathType != 'script') {
+            $expectedPaths = $expectedPaths[$prefix];
         }
 
+        array_push($expectedPaths, 'baz' . DIRECTORY_SEPARATOR);
+        array_push($expectedPaths, 'bar' . DIRECTORY_SEPARATOR);
+        array_push($expectedPaths, 'foo' . DIRECTORY_SEPARATOR);
+
         // add paths
         $func = 'add' . ucfirst($pathType) . 'Path';
         $view->$func('baz');    // no separator
@@ -180,7 +193,16 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
         $reflector   = $view->getAllPaths();
         $actualPaths = $reflector[$pathType];
 
-        $this->assertSame($expectedPaths, $actualPaths);
+        switch ($pathType) {
+            case 'script':
+                $this->assertSame(array_reverse($expectedPaths), $actualPaths);
+                break;
+            case 'helper':
+            case 'filter':
+            default:
+                $this->assertTrue(array_key_exists($prefix, $actualPaths));
+                $this->assertSame($expectedPaths, $actualPaths[$prefix], 'Actual: ' . var_export($actualPaths, 1) . "\nExpected: " . var_export($expectedPaths, 1));
+        }
     }
 
     /**
@@ -222,7 +244,7 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
             )
         );
 
-        $this->assertEquals('foo', $view->stub1());
+        $this->assertEquals('foo', $view->stub1(), var_export($view->getHelperPaths(), 1));
         $this->assertEquals('bar', $view->stub2());
 
         // erase the paths to the helper stubs
@@ -242,9 +264,9 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
 
         try {
             $view->nonexistantHelper();
-            // @todo: fail if no exception?
-        } catch (Zend_View_Exception $e) {
-            $this->assertRegexp('/helper [\'a-z]+ not found in path/i', $e->getMessage());
+            // @todo  fail if no exception?
+        } catch (Zend_Exception $e) {
+            $this->assertContains('not found', $e->getMessage());
         }
     }
 
@@ -262,12 +284,23 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
             // attempt to load the helper StubEmpty, whose file exists but
             // does not contain the expected class within
             $view->stubEmpty();	
-            // @todo: fail if no exception?
-        } catch (Zend_View_Exception $e) {
-            $this->assertRegexp("/['_a-z]+ not found in path/i", $e->getMessage());
+            // @todo  fail if no exception?
+        } catch (Zend_Exception $e) {
+            $this->assertContains("not found", $e->getMessage());
         }
     }
 
+    public function testHelperPathMayBeRegisteredUnderMultiplePrefixes()
+    {
+        $view = new Zend_View();
+
+        $view->addHelperPath(dirname(__FILE__) . '/View/_stubs/HelperDir1', 'Foo_View_Helper');
+        $view->addHelperPath(dirname(__FILE__) . '/View/_stubs/HelperDir1', 'Zend_View_Helper');
+
+        $helper = $view->getHelper('Stub1');
+        $this->assertTrue($helper instanceof Foo_View_Helper_Stub1);
+    }
+
     /**
      * Tests that render() can render a template.
      */
@@ -381,7 +414,7 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
             $this->fail('Rendering a template when no script path is set should raise an exception');
         } catch (Exception $e) {
             // success...
-            // @todo: assert something?
+            // @todo  assert something?
         }
     }
 
@@ -481,21 +514,31 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
 
         $found  = false;
         $prefix = false;
-        foreach ($helperPaths as $pathInfo) {
+        foreach ($helperPaths as $helperPrefix => $paths) {
+            foreach ($paths as $path) {
+                if (strstr($path, $helperPath)) {
+                    $found  = true;
+                    $prefix = $helperPrefix;
+                }
+            }
+            /*
             if (strstr($pathInfo['dir'], $helperPath)) {
                 $found  = true;
                 $prefix = $pathInfo['prefix'];
             }
+             */
         }
         $this->assertTrue($found, var_export($helperPaths, 1));
         $this->assertEquals('My_View_Helper_', $prefix);
 
         $found  = false;
         $prefix = false;
-        foreach ($filterPaths as $pathInfo) {
-            if (strstr($pathInfo['dir'], $filterPath)) {
-                $found  = true;
-                $prefix = $pathInfo['prefix'];
+        foreach ($filterPaths as $classPrefix => $paths) {
+            foreach ($paths as $pathInfo) {
+                if (strstr($pathInfo, $filterPath)) {
+                    $found  = true;
+                    $prefix = $classPrefix;
+                }
             }
         }
         $this->assertTrue($found, var_export($filterPaths, 1));
@@ -506,7 +549,7 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
     {
         $view = new Zend_View();
         unset($view->_path);
-        // @todo: assert something?
+        // @todo  assert something?
     }
 
     public function testSetProtectedThrowsException()
@@ -517,7 +560,7 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
             $this->fail('Should not be able to set protected properties');
         } catch (Exception $e) {
             // success
-            // @todo: assert something?
+            // @todo  assert something?
         }
     }
 
@@ -527,15 +570,15 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
         $status = $view->addHelperPath(dirname(__FILE__) . '/View/_stubs/HelperDir1/', 'My_View_Helper');
         $this->assertSame($view, $status);
         $helperPaths = $view->getHelperPaths();
-        $path = $helperPaths[0];
-        $this->assertEquals('My_View_Helper_', $path['prefix']);
-        $this->assertEquals($this->normalizePath(dirname(__FILE__) . '/View/_stubs/HelperDir1/'), $path['dir']);
+        $this->assertTrue(array_key_exists('My_View_Helper_', $helperPaths));
+        $path = current($helperPaths['My_View_Helper_']);
+        $this->assertEquals($this->normalizePath(dirname(__FILE__) . '/View/_stubs/HelperDir1/'), $path);
 
         $view->setHelperPath(dirname(__FILE__) . '/View/_stubs/HelperDir2/', 'Other_View_Helper');
         $helperPaths = $view->getHelperPaths();
-        $path = $helperPaths[0];
-        $this->assertEquals('Other_View_Helper_', $path['prefix']);
-        $this->assertEquals($this->normalizePath(dirname(__FILE__) . '/View/_stubs/HelperDir2/'), $path['dir']);
+        $this->assertTrue(array_key_exists('Other_View_Helper_', $helperPaths));
+        $path = current($helperPaths['Other_View_Helper_']);
+        $this->assertEquals($this->normalizePath(dirname(__FILE__) . '/View/_stubs/HelperDir2/'), $path);
     }
 
     public function testHelperPathWithPrefixAndRelativePath()
@@ -544,9 +587,8 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
         $status = $view->addHelperPath('Zend/View/_stubs/HelperDir1/', 'My_View_Helper');
         $this->assertSame($view, $status);
         $helperPaths = $view->getHelperPaths();
-        $path = $helperPaths[0];
-        $this->assertEquals('My_View_Helper_', $path['prefix']);
-        $this->assertContains($this->normalizePath('Zend/View/_stubs/HelperDir1/'), $path['dir']);
+        $this->assertTrue(array_key_exists('My_View_Helper_', $helperPaths));
+        $this->assertContains($this->normalizePath('Zend/View/_stubs/HelperDir1/'), current($helperPaths['My_View_Helper_']));
     }
 
     public function testFilterPathWithPrefix()
@@ -555,15 +597,13 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
         $status = $view->addFilterPath(dirname(__FILE__) . '/View/_stubs/HelperDir1/', 'My_View_Filter');
         $this->assertSame($view, $status);
         $filterPaths = $view->getFilterPaths();
-        $path = $filterPaths[0];
-        $this->assertEquals('My_View_Filter_', $path['prefix']);
-        $this->assertEquals($this->normalizePath(dirname(__FILE__) . '/View/_stubs/HelperDir1/'), $path['dir']);
+        $this->assertTrue(array_key_exists('My_View_Filter_', $filterPaths));
+        $this->assertEquals($this->normalizePath(dirname(__FILE__) . '/View/_stubs/HelperDir1/'), current($filterPaths['My_View_Filter_']));
 
         $view->setFilterPath(dirname(__FILE__) . '/View/_stubs/HelperDir2/', 'Other_View_Filter');
         $filterPaths = $view->getFilterPaths();
-        $path = $filterPaths[0];
-        $this->assertEquals('Other_View_Filter_', $path['prefix']);
-        $this->assertEquals($this->normalizePath(dirname(__FILE__) . '/View/_stubs/HelperDir2/'), $path['dir']);
+        $this->assertTrue(array_key_exists('Other_View_Filter_', $filterPaths));
+        $this->assertEquals($this->normalizePath(dirname(__FILE__) . '/View/_stubs/HelperDir2/'), current($filterPaths['Other_View_Filter_']));
     }
 
     public function testAssignThrowsExceptionsOnBadValues()
@@ -574,7 +614,7 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
             $this->fail('Protected/private properties cannot be assigned');
         } catch (Exception $e) {
             // success
-            // @todo: assert something?
+            // @todo  assert something?
         }
 
         try {
@@ -582,7 +622,7 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
             $this->fail('Protected/private properties cannot be assigned');
         } catch (Exception $e) {
             // success
-            // @todo: assert something?
+            // @todo  assert something?
         }
 
         try {
@@ -590,7 +630,7 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
             $this->fail('Assign spec requires string or array');
         } catch (Exception $e) {
             // success
-            // @todo: assert something?
+            // @todo  assert something?
         }
     }
 
@@ -709,11 +749,13 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
 
         $found  = false;
         $prefix = false;
-        foreach ($helperPaths as $path) {
-            if ($path['dir'] == $base . DIRECTORY_SEPARATOR . 'helpers' . DIRECTORY_SEPARATOR) {
-                $found  = true;
-                $prefix = $path['prefix'];
-                break;
+        foreach ($helperPaths as $pathPrefix => $paths) {
+            foreach ($paths as $path) {
+                if ($path == $base . DIRECTORY_SEPARATOR . 'helpers' . DIRECTORY_SEPARATOR) {
+                    $found  = true;
+                    $prefix = $pathPrefix;
+                    break;
+                }
             }
         }
         $this->assertTrue($found, var_export($helperPaths, 1));
@@ -724,11 +766,13 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
 
         $found  = false;
         $prefix = false;
-        foreach ($filterPaths as $path) {
-            if ($path['dir'] == $base . DIRECTORY_SEPARATOR . 'filters' . DIRECTORY_SEPARATOR) {
-                $found  = true;
-                $prefix = $path['prefix'];
-                break;
+        foreach ($filterPaths as $pathPrefix => $paths) {
+            foreach ($paths as $path) {
+                if ($path == $base . DIRECTORY_SEPARATOR . 'filters' . DIRECTORY_SEPARATOR) {
+                    $found  = true;
+                    $prefix = $pathPrefix;
+                    break;
+                }
             }
         }
         $this->assertTrue($found, var_export($filterPaths, 1));
@@ -738,14 +782,27 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
         }
     }
 
+    public function handleNotices($errno, $errstr, $errfile, $errline)
+    {
+        if (!isset($this->notices)) {
+            $this->notices = array();
+        }
+        if ($errno === E_USER_NOTICE) {
+            $this->notices[] = $errstr;
+        }
+    }
+
     public function testStrictVars()
     {
         $view = new Zend_View();
         $view->setScriptPath(dirname(__FILE__) . DIRECTORY_SEPARATOR . 'View' . DIRECTORY_SEPARATOR . '_templates');
         $view->strictVars(true);
+        set_error_handler(array($this, 'handleNotices'), E_USER_NOTICE);
         $content = $view->render('testStrictVars.phtml');
-        $this->assertContains('Key "foo" does not exist', $content, $content);
-        $this->assertContains('Key "bar" does not exist', $content);
+        restore_error_handler();
+        foreach (array('foo', 'bar') as $key) {
+            $this->assertContains('Key "' . $key . '" does not exist', $this->notices);
+        }
     }
 
     public function testGetScriptPath()
@@ -776,7 +833,7 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
         $view = new Zend_View();
         $view->declareVars();
         $helperPath = $view->getHelperPath('declareVars');
-        $this->assertEquals($expected, $helperPath);
+        $this->assertContains($helperPath, $expected);
     }
 
     public function testGetFilter()
@@ -854,13 +911,58 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
 
         $this->assertSame($helper1, $helper2);
     }
+    
+    /**
+     * @issue ZF-2742
+     */
+    public function testGetHelperWorksWithPredefinedClassNames()
+    {
+        $view = new Zend_View();
+
+        $view->setHelperPath(dirname(__FILE__) . '/View/_stubs/HelperDir2');
+        try {
+            $view->setHelperPath(dirname(__FILE__) . '/View/_stubs/HelperDir1', null);
+            $this->fail('Exception for empty prefix was expected.');
+        } catch (Exception $e) {
+            $this->assertContains('only takes strings', $e->getMessage());
+        }
+
+        try {
+            $view->setHelperPath(dirname(__FILE__) . '/View/_stubs/HelperDir1', null);
+            $this->fail('Exception for empty prefix was expected.');
+        } catch (Exception $e) {
+            $this->assertContains('only takes strings', $e->getMessage());
+        }
+        
+        
+        try {
+            $helper = $view->getHelper('Datetime');
+        } catch (Exception $e) {
+            $this->assertContains('not found', $e->getMessage());
+        }
+    }
+
+    public function testUseStreamWrapperFlagShouldDefaultToFalse()
+    {
+        $this->view = new Zend_View();
+        $this->assertFalse($this->view->useStreamWrapper());
+    }
+    
+    public function testUseStreamWrapperStateShouldBeConfigurable()
+    {
+        $this->testUseStreamWrapperFlagShouldDefaultToFalse();
+        $this->view->setUseStreamWrapper(true);
+        $this->assertTrue($this->view->useStreamWrapper());
+        $this->view->setUseStreamWrapper(false);
+        $this->assertFalse($this->view->useStreamWrapper());
+    }
 }
 
 /**
  * @category   Zend
  * @package    Zend_View
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2007 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 class Zend_ViewTest_Extension extends Zend_View
@@ -871,3 +973,8 @@ class Zend_ViewTest_Extension extends Zend_View
         $this->setScriptPath(dirname(__FILE__) . '/View/_templates');
     }
 }
+
+// Call Zend_ViewTest::main() if this source file is executed directly.
+if (PHPUnit_MAIN_METHOD == "Zend_ViewTest::main") {
+    Zend_ViewTest::main();
+}
